;;;
;;; mit-scheme-doc --- Browse MIT-scheme documentation. Based on
;;; r5rs.el by Numa Tortolero

;; Author: Robert McIntyre <rlm@mit.edu>

;; This file is not part of GNU Emacs, but distributed under the same
;; conditions as GNU Emacs, and is useless without GNU Emacs.

;; GNU Emacs is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; GNU Emacs is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Commentary:

;;; Code:

(require 'cl)
(require 'browse-url)			; you need Emacs version 20 or greater
(require 'thingatpt)

(defvar mit-scheme-doc-root
  "http://www.gnu.org/software/mit-scheme/documentation/mit-scheme-ref/"
  "If you copy scheme documentation to your local system, set this variable to
   something like \"file:/usr/local/doc/mit-scheme-ref/\".")

(defvar mit-scheme-doc-history nil
  "History of symbols looked up in the Scheme R5rs.")

;; if only we had had packages or hash tables..., but let's fake it.
(defvar mit-scheme-doc-symbols (make-vector 67 0))

(defun mit-scheme-doc-lookup (symbol-name)
  "View the documentation on SYMBOL-NAME from the Scheme R5rs.
If SYMBOL-NAME has more than one definition, all of them are displayed with
your favorite browser in sequence.  The browser should have a \"back\"
function to view the separate definitions.
The Scheme R5RS is the Revised5 Report on the Algorithmic Language Schema, provided
by Richard Kelsey, William Clinger, and Jonathan Rees (Editors).
The report gives a defining description of the programming language Scheme. 
Scheme is a statically scoped and properly tail-recursive dialect of the Lisp 
programming language invented by Guy Lewis Steele Jr. and Gerald Jay Sussman. 
It was designed to have an exceptionally clear and simple semantics and few 
different ways to form expressions.
By default, the R5RS WWW site is visited to retrieve the information.
If you copy the R5rs to another location, customize the
variable `mit-scheme-doc-root' to point to that location."
  (interactive (list (let ((symbol-at-point (thing-at-point 'symbol)))
		       (if (and symbol-at-point
				(intern-soft (downcase symbol-at-point)
					     mit-scheme-doc-symbols))
			   symbol-at-point
		       (completing-read
			"Look up symbol in mit scheme docs: "
			mit-scheme-doc-symbols #'boundp
			t symbol-at-point
			'mit-scheme-doc-history)))))
  (maplist (lambda (entry)
	     (browse-url (concat mit-scheme-doc-root "" (car entry))
			 browse-url-new-window-flag)
	   (if (cdr entry)
	       (sleep-for 1.5)))
	   (let ((symbol (intern-soft (downcase symbol-name)
				    mit-scheme-doc-symbols)))
	     (if (and symbol (boundp symbol))
		 (symbol-value symbol)
	       (error "The symbol `%s' is not defined in mit-scheme"
		    symbol-name)))))

(mapc (lambda (entry)
	  (let ((symbol (intern (car entry) mit-scheme-doc-symbols)))
	    (if (boundp symbol)
	      (push (cadr entry) (symbol-value symbol))
	      (set symbol (cdr entry)))))
      
      '(("#" "Syntax-of-numerical-constants.html#index-g_t_0023-457")
	("#!optional" "Lambda-Expressions.html#index-g_t_0023_0021optional-204")
	("#!optional" "Additional-Notations.html#index-g_t_0023_0021optional-148")
	("#!rest" "Lambda-Expressions.html#index-g_t_0023_0021rest-205")
	("#!rest" "Additional-Notations.html#index-g_t_0023_0021rest-149")
	("#(" "Vectors.html#index-g_t_0023_0028-1309")
	("#\\" "External-Representation-of-Characters.html#index-g_t_0023_005c-685")
	("#\\altmode" "External-Representation-of-Characters.html#index-g_t_0023_005caltmode-696")
	("#\\backnext" "External-Representation-of-Characters.html#index-g_t_0023_005cbacknext-697")
	("#\\backspace" "External-Representation-of-Characters.html#index-g_t_0023_005cbackspace-698")
	("#\\call" "External-Representation-of-Characters.html#index-g_t_0023_005ccall-699")
	("#\\linefeed" "External-Representation-of-Characters.html#index-g_t_0023_005clinefeed-700")
	("#\\linefeed" "Character-Sets.html#index-g_t_0023_005clinefeed-791")
	("#\\newline" "Strings.html#index-g_t_0023_005cnewline-881")
	("#\\newline" "External-Representation-of-Characters.html#index-g_t_0023_005cnewline-687")
	("#\\newline" "Character-Sets.html#index-g_t_0023_005cnewline-793")
	("#\\page" "Character-Sets.html#index-g_t_0023_005cpage-790")
	("#\\page" "Strings.html#index-g_t_0023_005cpage-882")
	("#\\page" "External-Representation-of-Characters.html#index-g_t_0023_005cpage-701")
	("#\\return" "Character-Sets.html#index-g_t_0023_005creturn-792")
	("#\\return" "External-Representation-of-Characters.html#index-g_t_0023_005creturn-702")
	("#\\rubout" "External-Representation-of-Characters.html#index-g_t_0023_005crubout-703")
	("#\\space" "External-Representation-of-Characters.html#index-g_t_0023_005cspace-704")
	("#\\space" "Character-Sets.html#index-g_t_0023_005cspace-788")
	("#\\space" "Cutting-and-Pasting-Strings.html#index-g_t_0023_005cspace-965")
	("#\\space" "External-Representation-of-Characters.html#index-g_t_0023_005cspace-686")
	("#\\tab" "Character-Sets.html#index-g_t_0023_005ctab-789")
	("#\\tab" "External-Representation-of-Characters.html#index-g_t_0023_005ctab-705")
	("#\\tab" "Strings.html#index-g_t_0023_005ctab-880")
	("#b" "Syntax-of-numerical-constants.html#index-g_t_0023b-447")
	("#d" "Syntax-of-numerical-constants.html#index-g_t_0023d-449")
	("#e" "Syntax-of-numerical-constants.html#index-g_t_0023e-455")
	("#f" "Booleans.html#index-g_t_0023f-1421")
	("#f" "Conditionals.html#index-g_t_0023f-303")
	("#f" "True-and-False.html#index-g_t_0023f-104")
	("#i" "Syntax-of-numerical-constants.html#index-g_t_0023i-456")
	("#o" "Syntax-of-numerical-constants.html#index-g_t_0023o-448")
	("#t" "Conditionals.html#index-g_t_0023t-304")
	("#t" "Booleans.html#index-g_t_0023t-1420")
	("#t" "True-and-False.html#index-g_t_0023t-103")
	("#x" "Syntax-of-numerical-constants.html#index-g_t_0023x-450")
	("'" "Quoting.html#index-g_t_0027-282")
	("'" "Lists.html#index-g_t_0027-1113")
	("(" "Lists.html#index-g_t_0028-1098")
	("()" "Lists.html#index-g_t_0028_0029-1105")
	(")" "Lists.html#index-g_t_0029-1099")
	("*" "_002aMatcher.html#index-g_t_002a-2285")
	("*" "Procedure-Call-Syntax.html#index-g_t_002a-174")
	("*" "_002aParser.html#index-g_t_002a-2299")
	("*" "Numerical-operations.html#index-g_t_002a-512")
	("*default-pathname-defaults*" "Operations-on-Pathnames.html#index-g_t_002adefault_002dpathname_002ddefaults_002a-2535")
	("*matcher" "_002aMatcher.html#index-g_t_002amatcher-2273")
	("*parser" "_002aParser.html#index-g_t_002aparser-2292")
	("*parser-canonicalize-symbols?*" "Input-Procedures.html#index-g_t_002aparser_002dcanonicalize_002dsymbols_003f_002a-2080")
	("*parser-radix*" "Input-Procedures.html#index-g_t_002aparser_002dradix_002a-2079")
	("*random-state*" "Random-Numbers.html#index-g_t_002arandom_002dstate_002a-679")
	("*unparse-with-maximum-readability?*" "Output-Procedures.html#index-g_t_002aunparse_002dwith_002dmaximum_002dreadability_003f_002a-2118")
	("*unparser-list-breadth-limit*" "Output-Procedures.html#index-g_t_002aunparser_002dlist_002dbreadth_002dlimit_002a-2115")
	("*unparser-list-depth-limit*" "Output-Procedures.html#index-g_t_002aunparser_002dlist_002ddepth_002dlimit_002a-2116")
	("*unparser-radix*" "Output-Procedures.html#index-g_t_002aunparser_002dradix_002a-2114")
	("*unparser-string-length-limit*" "Output-Procedures.html#index-g_t_002aunparser_002dstring_002dlength_002dlimit_002a-2117")
	("+" "_002aParser.html#index-g_t_002b-2300")
	("+" "Exactness.html#index-g_t_002b-437")
	("+" "_002aMatcher.html#index-g_t_002b-2286")
	("+" "Procedure-Call-Syntax.html#index-g_t_002b-173")
	("+" "Numerical-operations.html#index-g_t_002b-511")
	("+inf" "Flonum-Operations.html#index-g_t_002binf-646")
	("," "Lists.html#index-g_t_002c-1115")
	("," "Quoting.html#index-g_t_002c-297")
	(",@" "Quoting.html#index-g_t_002c_0040_0040-298")
	(",@" "Lists.html#index-g_t_002c_0040_0040-1116")
	("-" "Numerical-operations.html#index-g_t_002d-519")
	("-1+" "Numerical-operations.html#index-g_t_002d1_002b-528")
	("->namestring" "Filenames-and-Pathnames.html#index-g_t_002d_003enamestring-2487")
	("->pathname" "Working-Directory.html#index-g_t_002d_003epathname-2577")
	("->pathname" "Filenames-and-Pathnames.html#index-g_t_002d_003epathname-2483")
	("->truename" "File-Manipulation.html#index-g_t_002d_003etruename-2602")
	("-inf" "Flonum-Operations.html#index-g_t_002dinf-647")
	("." "Lists.html#index-g_t_002e-1100")
	("..." "Pattern-Language.html#index-g_t_002e_002e_002e-378")
	("/" "Implementation-restrictions.html#index-g_t_002f-443")
	("/" "Numerical-operations.html#index-g_t_002f-520")
	("1+" "Numerical-operations.html#index-g_t1_002b-527")
	("1d-table/alist" "1D-Tables.html#index-g_t1d_002dtable_002falist-1633")
	("1d-table/get" "1D-Tables.html#index-g_t1d_002dtable_002fget-1631")
	("1d-table/lookup" "1D-Tables.html#index-g_t1d_002dtable_002flookup-1632")
	("1d-table/put!" "1D-Tables.html#index-g_t1d_002dtable_002fput_0021-1629")
	("1d-table/remove!" "1D-Tables.html#index-g_t1d_002dtable_002fremove_0021-1630")
	("1d-table?" "1D-Tables.html#index-g_t1d_002dtable_003f-1626")
	("2d-get" "The-Association-Table.html#index-g_t2d_002dget-1640")
	("2d-get-alist-x" "The-Association-Table.html#index-g_t2d_002dget_002dalist_002dx-1641")
	("2d-get-alist-y" "The-Association-Table.html#index-g_t2d_002dget_002dalist_002dy-1642")
	("2d-put!" "The-Association-Table.html#index-g_t2d_002dput_0021-1638")
	("2d-remove!" "The-Association-Table.html#index-g_t2d_002dremove_0021-1639")
	("8-bit-char-set?" "Character-Sets.html#index-g_t8_002dbit_002dchar_002dset_003f-815")
	("<" "Numerical-operations.html#index-g_t_003c-489")
	("<=" "Internal-Representation-of-Characters.html#index-g_t_003c_003d-754")
	("<=" "Numerical-operations.html#index-g_t_003c_003d-491")
	("<xml-!attlist>" "XML-Structure.html#index-g_t_003cxml_002d_0021attlist_003e-2427")
	("<xml-!element>" "XML-Structure.html#index-g_t_003cxml_002d_0021element_003e-2419")
	("<xml-!entity>" "XML-Structure.html#index-g_t_003cxml_002d_0021entity_003e-2435")
	("<xml-!notation>" "XML-Structure.html#index-g_t_003cxml_002d_0021notation_003e-2461")
	("<xml-declaration>" "XML-Structure.html#index-g_t_003cxml_002ddeclaration_003e-2381")
	("<xml-document>" "XML-Structure.html#index-g_t_003cxml_002ddocument_003e-2365")
	("<xml-dtd>" "XML-Structure.html#index-g_t_003cxml_002ddtd_003e-2409")
	("<xml-element>" "XML-Structure.html#index-g_t_003cxml_002delement_003e-2391")
	("<xml-external-id>" "XML-Structure.html#index-g_t_003cxml_002dexternal_002did_003e-2469")
	("<xml-parameter-!entity>" "XML-Structure.html#index-g_t_003cxml_002dparameter_002d_0021entity_003e-2443")
	("<xml-processing-instructions>" "XML-Structure.html#index-g_t_003cxml_002dprocessing_002dinstructions_003e-2401")
	("<xml-unparsed-!entity>" "XML-Structure.html#index-g_t_003cxml_002dunparsed_002d_0021entity_003e-2451")
	("=" "Equivalence-Predicates.html#index-g_t_003d-429")
	("=" "Numerical-operations.html#index-g_t_003d-488")
	("=" "Comparison-of-Strings.html#index-g_t_003d-934")
	("=" "Numerical-operations.html#index-g_t_003d-482")
	("=>" "Conditionals.html#index-g_t_003d_003e-312")
	(">" "Numerical-operations.html#index-g_t_003e-490")
	(">=" "Numerical-operations.html#index-g_t_003e_003d-492")
	("?" "_002aParser.html#index-g_t_003f-2301")
	("?" "_002aMatcher.html#index-g_t_003f-2287")
	("\\" "Strings.html#index-g_t_005c-876")
	("\\f" "Strings.html#index-g_t_005cf-879")
	("\\n" "Strings.html#index-g_t_005cn-878")
	("\\t" "Strings.html#index-g_t_005ct-877")
	("`" "Lists.html#index-g_t_0060-1114")
	("`" "Quoting.html#index-g_t_0060-296")
	("abort" "Invoking-Standard-Restart-Code.html#index-abort-2857")
	("abort" "Restarts.html#index-abort-2845")
	("abs" "Numerical-operations.html#index-abs-529")
	("access" "Assignments.html#index-access-273")
	("access-condition" "Generating-Operations-on-Conditions.html#index-access_002dcondition-2903")
	("access-condition" "Simple-Condition-Instance-Operations.html#index-access_002dcondition-2919")
	("acos" "Numerical-operations.html#index-acos-577")
	("add-generic-procedure-generator" "Method-Generators.html#index-add_002dgeneric_002dprocedure_002dgenerator-1887")
	("alist->rb-tree" "Red_002dBlack-Trees.html#index-alist_002d_003erb_002dtree-1738")
	("alist->wt-tree" "Construction-of-Weight_002dBalanced-Trees.html#index-alist_002d_003ewt_002dtree-1767")
	("alist-copy" "Association-Lists.html#index-alist_002dcopy-1617")
	("alist?" "Association-Lists.html#index-alist_003f-1590")
	("allocate-host-address" "Miscellaneous-OS-Facilities.html#index-allocate_002dhost_002daddress-2755")
	("alt" "_002aParser.html#index-alt-2298")
	("alt" "_002aMatcher.html#index-alt-2284")
	("and" "Conditionals.html#index-and-319")
	("and" "Booleans.html#index-and-1429")
	("and-let*" "and_002dlet_002a-_0028SRFI-2_0029.html#index-and_002dlet_002a-412")
	("angle" "Numerical-operations.html#index-angle-580")
	("any" "Reduction-of-Lists.html#index-any-1283")
	("append" "Cutting-and-Pasting-Lists.html#index-append-1214")
	("append!" "Cutting-and-Pasting-Lists.html#index-append_0021-1216")
	("append-map" "Mapping-of-Lists.html#index-append_002dmap-1271")
	("append-map!" "Mapping-of-Lists.html#index-append_002dmap_0021-1273")
	("append-map*" "Mapping-of-Lists.html#index-append_002dmap_002a-1270")
	("append-map*!" "Mapping-of-Lists.html#index-append_002dmap_002a_0021-1276")
	("apply" "Procedure-Operations.html#index-apply-1813")
	("apply-hook-extra" "Application-Hooks.html#index-apply_002dhook_002dextra-1867")
	("apply-hook-procedure" "Application-Hooks.html#index-apply_002dhook_002dprocedure-1865")
	("apply-hook?" "Application-Hooks.html#index-apply_002dhook_003f-1863")
	("ascii->char" "ISO_002d8859_002d1-Characters.html#index-ascii_002d_003echar-761")
	("ascii-range->char-set" "Character-Sets.html#index-ascii_002drange_002d_003echar_002dset-816")
	("asin" "Numerical-operations.html#index-asin-576")
	("assoc" "Association-Lists.html#index-assoc-1595")
	("association-procedure" "Association-Lists.html#index-association_002dprocedure-1600")
	("assq" "Association-Lists.html#index-assq-1593")
	("assv" "Association-Lists.html#index-assv-1594")
	("atan" "Numerical-operations.html#index-atan-578")
	("atan" "Flonum-Operations.html#index-atan-673")
	("atan" "Numerical-operations.html#index-atan-579")
	("beep" "Output-Procedures.html#index-beep-2102")
	("begin" "Sequencing.html#index-begin-322")
	("bind-cell-contents!" "Cells.html#index-bind_002dcell_002dcontents_0021-1496")
	("bind-condition-handler" "Condition-Handling.html#index-bind_002dcondition_002dhandler-2810")
	("bind-condition-handler" "Condition-Signalling.html#index-bind_002dcondition_002dhandler-2793")
	("bind-condition-handler" "Error-System.html#index-bind_002dcondition_002dhandler-2768")
	("bind-default-condition-handler" "Condition-Handling.html#index-bind_002ddefault_002dcondition_002dhandler-2804")
	("bind-default-condition-handler" "Condition-Signalling.html#index-bind_002ddefault_002dcondition_002dhandler-2792")
	("bind-default-condition-handler" "Condition-Handling.html#index-bind_002ddefault_002dcondition_002dhandler-2812")
	("bit-string->signed-integer" "Integer-Conversions-of-Bit-Strings.html#index-bit_002dstring_002d_003esigned_002dinteger-1419")
	("bit-string->unsigned-integer" "Integer-Conversions-of-Bit-Strings.html#index-bit_002dstring_002d_003eunsigned_002dinteger-1418")
	("bit-string-allocate" "Construction-of-Bit-Strings.html#index-bit_002dstring_002dallocate-1372")
	("bit-string-and" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dand-1399")
	("bit-string-and!" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dand_0021-1403")
	("bit-string-andc" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dandc-1400")
	("bit-string-andc!" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dandc_0021-1406")
	("bit-string-append" "Cutting-and-Pasting-Bit-Strings.html#index-bit_002dstring_002dappend-1388")
	("bit-string-clear!" "Selecting-Bit-String-Components.html#index-bit_002dstring_002dclear_0021-1383")
	("bit-string-copy" "Construction-of-Bit-Strings.html#index-bit_002dstring_002dcopy-1373")
	("bit-string-fill!" "Modification-of-Bit-Strings.html#index-bit_002dstring_002dfill_0021-1410")
	("bit-string-length" "Selecting-Bit-String-Components.html#index-bit_002dstring_002dlength-1377")
	("bit-string-move!" "Modification-of-Bit-Strings.html#index-bit_002dstring_002dmove_0021-1411")
	("bit-string-movec!" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dmovec_0021-1398")
	("bit-string-not" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dnot-1396")
	("bit-string-or" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dor-1401")
	("bit-string-or!" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dor_0021-1404")
	("bit-string-ref" "Selecting-Bit-String-Components.html#index-bit_002dstring_002dref-1379")
	("bit-string-set!" "Selecting-Bit-String-Components.html#index-bit_002dstring_002dset_0021-1382")
	("bit-string-xor" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dxor-1402")
	("bit-string-xor!" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dxor_0021-1405")
	("bit-string-zero?" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_002dzero_003f-1392")
	("bit-string=?" "Bitwise-Operations-on-Bit-Strings.html#index-bit_002dstring_003d_003f-1393")
	("bit-string?" "Selecting-Bit-String-Components.html#index-bit_002dstring_003f-1375")
	("bit-substring" "Cutting-and-Pasting-Bit-Strings.html#index-bit_002dsubstring-1390")
	("bit-substring-find-next-set-bit" "Selecting-Bit-String-Components.html#index-bit_002dsubstring_002dfind_002dnext_002dset_002dbit-1384")
	("bit-substring-move-right!" "Modification-of-Bit-Strings.html#index-bit_002dsubstring_002dmove_002dright_0021-1412")
	("bitmap-from-dib" "DIB-procedures.html#index-bitmap_002dfrom_002ddib-3170")
	("bool" "Windows-Types.html#index-bool-3128")
	("boolean/and" "Booleans.html#index-boolean_002fand-1445")
	("boolean/or" "Booleans.html#index-boolean_002for-1446")
	("boolean=?" "Booleans.html#index-boolean_003d_003f-1441")
	("boolean?" "Booleans.html#index-boolean_003f-1435")
	("bound-restart" "Finding-and-Invoking-General-Restart-Code.html#index-bound_002drestart-2871")
	("bound-restarts" "Finding-and-Invoking-General-Restart-Code.html#index-bound_002drestarts-2875")
	("break-on-signals" "Condition-Signalling.html#index-break_002don_002dsignals-2791")
	("break-on-signals" "Condition-Handling.html#index-break_002don_002dsignals-2814")
	("buffered-input-chars on input port" "Input-Port-Operations.html#index-buffered_002dinput_002dchars-on-input-port-2190")
	("buffered-output-chars on output port" "Output-Port-Operations.html#index-buffered_002doutput_002dchars-on-output-port-2207")
	("built-in-dispatch-tag" "Dispatch-Tags.html#index-built_002din_002ddispatch_002dtag-1896")
	("built-in-dispatch-tags" "Dispatch-Tags.html#index-built_002din_002ddispatch_002dtags-1897")
	("byte" "Windows-Types.html#index-byte-3137")
	("caaaar" "Pairs.html#index-caaaar-1143")
	("caaadr" "Pairs.html#index-caaadr-1144")
	("caaar" "Pairs.html#index-caaar-1135")
	("caadar" "Pairs.html#index-caadar-1145")
	("caaddr" "Pairs.html#index-caaddr-1146")
	("caadr" "Pairs.html#index-caadr-1136")
	("caar" "Pairs.html#index-caar-1131")
	("cadaar" "Pairs.html#index-cadaar-1147")
	("cadadr" "Pairs.html#index-cadadr-1148")
	("cadar" "Pairs.html#index-cadar-1137")
	("caddar" "Pairs.html#index-caddar-1149")
	("cadddr" "Pairs.html#index-cadddr-1150")
	("caddr" "Pairs.html#index-caddr-1138")
	("cadr" "Pairs.html#index-cadr-1132")
	("call-with-binary-input-file" "File-Ports.html#index-call_002dwith_002dbinary_002dinput_002dfile-2027")
	("call-with-binary-output-file" "File-Ports.html#index-call_002dwith_002dbinary_002doutput_002dfile-2028")
	("call-with-current-continuation" "Continuations.html#index-call_002dwith_002dcurrent_002dcontinuation-1840")
	("call-with-input-file" "File-Ports.html#index-call_002dwith_002dinput_002dfile-2025")
	("call-with-output-file" "File-Ports.html#index-call_002dwith_002doutput_002dfile-2026")
	("call-with-output-string" "String-Ports.html#index-call_002dwith_002doutput_002dstring-2049")
	("call-with-temporary-file-pathname" "File-Manipulation.html#index-call_002dwith_002dtemporary_002dfile_002dpathname-2605")
	("call-with-values" "Continuations.html#index-call_002dwith_002dvalues-1853")
	("call-with-wide-output-string" "Wide-Strings.html#index-call_002dwith_002dwide_002doutput_002dstring-836")
	("canonical-host-name" "Miscellaneous-OS-Facilities.html#index-canonical_002dhost_002dname-2752")
	("capture-syntactic-environment" "SC-Transformer-Definition.html#index-capture_002dsyntactic_002denvironment-395")
	("car" "Pairs.html#index-car-1124")
	("car" "Streams.html#index-car-1540")
	("car" "Storage-Model.html#index-car-111")
	("car+cdr" "Pairs.html#index-car_002bcdr-1128")
	("case" "Sequencing.html#index-case-324")
	("case" "Conditionals.html#index-case-313")
	("cd" "Working-Directory.html#index-cd-2576")
	("cdaaar" "Pairs.html#index-cdaaar-1151")
	("cdaadr" "Pairs.html#index-cdaadr-1152")
	("cdaar" "Pairs.html#index-cdaar-1139")
	("cdadar" "Pairs.html#index-cdadar-1153")
	("cdaddr" "Pairs.html#index-cdaddr-1154")
	("cdadr" "Pairs.html#index-cdadr-1140")
	("cdar" "Pairs.html#index-cdar-1133")
	("cddaar" "Pairs.html#index-cddaar-1155")
	("cddadr" "Pairs.html#index-cddadr-1156")
	("cddar" "Pairs.html#index-cddar-1141")
	("cdddar" "Pairs.html#index-cdddar-1157")
	("cddddr" "Pairs.html#index-cddddr-1158")
	("cdddr" "Pairs.html#index-cdddr-1142")
	("cddr" "Pairs.html#index-cddr-1134")
	("cdr" "Streams.html#index-cdr-1544")
	("cdr" "Pairs.html#index-cdr-1127")
	("cdr" "Entry-Format.html#index-cdr-53")
	("ceiling" "Numerical-operations.html#index-ceiling-558")
	("ceiling->exact" "Numerical-operations.html#index-ceiling_002d_003eexact-562")
	("cell-contents" "Cells.html#index-cell_002dcontents-1492")
	("cell?" "Cells.html#index-cell_003f-1488")
	("char" "Windows-Types.html#index-char-3129")
	("char" "_002aMatcher.html#index-char-2274")
	("char*" "Windows-Types.html#index-char_002a-3139")
	("char->ascii" "ISO_002d8859_002d1-Characters.html#index-char_002d_003eascii-759")
	("char->ascii" "Internal-Representation-of-Characters.html#index-char_002d_003eascii-752")
	("char->digit" "Miscellaneous-Character-Operations.html#index-char_002d_003edigit-733")
	("char->integer" "Internal-Representation-of-Characters.html#index-char_002d_003einteger-749")
	("char->name" "External-Representation-of-Characters.html#index-char_002d_003ename-708")
	("char-alphabetic?" "Character-Sets.html#index-char_002dalphabetic_003f-796")
	("char-alphanumeric?" "Character-Sets.html#index-char_002dalphanumeric_003f-798")
	("char-ascii?" "Strings.html#index-char_002dascii_003f-868")
	("char-ascii?" "ISO_002d8859_002d1-Characters.html#index-char_002dascii_003f-758")
	("char-ascii?" "Internal-Representation-of-Characters.html#index-char_002dascii_003f-751")
	("char-bits" "Internal-Representation-of-Characters.html#index-char_002dbits-743")
	("char-bits-limit" "Internal-Representation-of-Characters.html#index-char_002dbits_002dlimit-748")
	("char-ci" "_002aMatcher.html#index-char_002dci-2275")
	("char-ci<=?" "Comparison-of-Characters.html#index-char_002dci_003c_003d_003f-722")
	("char-ci<?" "Comparison-of-Characters.html#index-char_002dci_003c_003f-720")
	("char-ci=?" "Miscellaneous-Character-Operations.html#index-char_002dci_003d_003f-732")
	("char-ci=?" "Comparison-of-Characters.html#index-char_002dci_003d_003f-719")
	("char-ci>=?" "Comparison-of-Characters.html#index-char_002dci_003e_003d_003f-723")
	("char-ci>?" "Comparison-of-Characters.html#index-char_002dci_003e_003f-721")
	("char-code" "Internal-Representation-of-Characters.html#index-char_002dcode-746")
	("char-code-limit" "Internal-Representation-of-Characters.html#index-char_002dcode_002dlimit-747")
	("char-downcase" "Miscellaneous-Character-Operations.html#index-char_002ddowncase-728")
	("char-graphic?" "Prompting.html#index-char_002dgraphic_003f-2143")
	("char-graphic?" "Character-Sets.html#index-char_002dgraphic_003f-800")
	("char-integer-limit" "Internal-Representation-of-Characters.html#index-char_002dinteger_002dlimit-755")
	("char-lower-case?" "Character-Sets.html#index-char_002dlower_002dcase_003f-795")
	("char-numeric?" "Character-Sets.html#index-char_002dnumeric_003f-797")
	("char-ready?" "Input-Procedures.html#index-char_002dready_003f-2061")
	("char-ready? on input port" "Input-Port-Operations.html#index-char_002dready_003f-on-input-port-2177")
	("char-set" "Character-Sets.html#index-char_002dset-804")
	("char-set" "_002aMatcher.html#index-char_002dset-2280")
	("char-set->scalar-values" "Character-Sets.html#index-char_002dset_002d_003escalar_002dvalues-809")
	("char-set-difference" "Character-Sets.html#index-char_002dset_002ddifference-812")
	("char-set-intersection" "Character-Sets.html#index-char_002dset_002dintersection-813")
	("char-set-invert" "Character-Sets.html#index-char_002dset_002dinvert-811")
	("char-set-member?" "Character-Sets.html#index-char_002dset_002dmember_003f-802")
	("char-set-members" "Character-Sets.html#index-char_002dset_002dmembers-817")
	("char-set-union" "Character-Sets.html#index-char_002dset_002dunion-814")
	("char-set:alphabetic" "Character-Sets.html#index-char_002dset_003aalphabetic-768")
	("char-set:alphanumeric" "Character-Sets.html#index-char_002dset_003aalphanumeric-770")
	("char-set:graphic" "Character-Sets.html#index-char_002dset_003agraphic-773")
	("char-set:lower-case" "Character-Sets.html#index-char_002dset_003alower_002dcase-767")
	("char-set:not-graphic" "Character-Sets.html#index-char_002dset_003anot_002dgraphic-774")
	("char-set:not-whitespace" "Character-Sets.html#index-char_002dset_003anot_002dwhitespace-772")
	("char-set:numeric" "Character-Sets.html#index-char_002dset_003anumeric-769")
	("char-set:standard" "Character-Sets.html#index-char_002dset_003astandard-775")
	("char-set:upper-case" "Character-Sets.html#index-char_002dset_003aupper_002dcase-766")
	("char-set:whitespace" "Character-Sets.html#index-char_002dset_003awhitespace-771")
	("char-set:whitespace" "Cutting-and-Pasting-Strings.html#index-char_002dset_003awhitespace-970")
	("char-set=?" "Character-Sets.html#index-char_002dset_003d_003f-803")
	("char-set?" "Character-Sets.html#index-char_002dset_003f-764")
	("char-standard?" "Character-Sets.html#index-char_002dstandard_003f-801")
	("char-upcase" "Miscellaneous-Character-Operations.html#index-char_002dupcase-727")
	("char-upper-case?" "Character-Sets.html#index-char_002dupper_002dcase_003f-794")
	("char-whitespace?" "Character-Sets.html#index-char_002dwhitespace_003f-799")
	("char<=?" "Comparison-of-Characters.html#index-char_003c_003d_003f-717")
	("char<=?" "Internal-Representation-of-Characters.html#index-char_003c_003d_003f-753")
	("char<?" "Comparison-of-Characters.html#index-char_003c_003f-715")
	("char=?" "Comparison-of-Characters.html#index-char_003d_003f-714")
	("char=?" "Equivalence-Predicates.html#index-char_003d_003f-430")
	("char>=?" "Comparison-of-Characters.html#index-char_003e_003d_003f-718")
	("char>?" "Comparison-of-Characters.html#index-char_003e_003f-716")
	("char?" "Miscellaneous-Character-Operations.html#index-char_003f-725")
	("chars->char-set" "Character-Sets.html#index-chars_002d_003echar_002dset-806")
	("chars-remaining on input port" "Input-Port-Operations.html#index-chars_002dremaining-on-input-port-2189")
	("circular-list" "Miscellaneous-List-Operations.html#index-circular_002dlist-1287")
	("circular-list?" "Selecting-List-Components.html#index-circular_002dlist_003f-1187")
	("clear" "Output-Procedures.html#index-clear-2106")
	("close-all-open-files" "File-Ports.html#index-close_002dall_002dopen_002dfiles-2023")
	("close-input-port" "Ports.html#index-close_002dinput_002dport-2000")
	("close-output-port" "Ports.html#index-close_002doutput_002dport-2001")
	("close-port" "Ports.html#index-close_002dport-1998")
	("close-syntax" "SC-Transformer-Definition.html#index-close_002dsyntax-394")
	("close-tcp-server-socket" "TCP-Sockets.html#index-close_002dtcp_002dserver_002dsocket-2746")
	("compiled-procedure?" "Procedure-Operations.html#index-compiled_002dprocedure_003f-1817")
	("complex?" "Numerical-operations.html#index-complex_003f-476")
	("compound-procedure?" "Procedure-Operations.html#index-compound_002dprocedure_003f-1819")
	("conc-name" "Structure-Definitions.html#index-conc_002dname-359")
	("cond" "Entry-Format.html#index-cond-43")
	("cond" "Conditionals.html#index-cond-306")
	("cond" "Booleans.html#index-cond-1428")
	("cond" "Sequencing.html#index-cond-325")
	("cond-expand" "cond_002dexpand-_0028SRFI-0_0029.html#index-cond_002dexpand-408")
	("condition-accessor" "Generating-Operations-on-Conditions.html#index-condition_002daccessor-2901")
	("condition-accessor" "Simple-Condition-Instance-Operations.html#index-condition_002daccessor-2920")
	("condition-accessor" "Generating-Operations-on-Conditions.html#index-condition_002daccessor-2894")
	("condition-constructor" "Generating-Operations-on-Conditions.html#index-condition_002dconstructor-2893")
	("condition-predicate" "Generating-Operations-on-Conditions.html#index-condition_002dpredicate-2904")
	("condition-signaller" "Generating-Operations-on-Conditions.html#index-condition_002dsignaller-2906")
	("condition-type/error?" "Condition-Types.html#index-condition_002dtype_002ferror_003f-2927")
	("condition-type/field-names" "Condition-Types.html#index-condition_002dtype_002ffield_002dnames-2930")
	("condition-type/generalizations" "Condition-Types.html#index-condition_002dtype_002fgeneralizations-2932")
	("condition-type:arithmetic-error" "Taxonomy.html#index-condition_002dtype_003aarithmetic_002derror-2961")
	("condition-type:bad-range-argument" "Object-Hashing.html#index-condition_002dtype_003abad_002drange_002dargument-1711")
	("condition-type:bad-range-argument" "Integer-Conversions-of-Bit-Strings.html#index-condition_002dtype_003abad_002drange_002dargument-1417")
	("condition-type:bad-range-argument" "ISO_002d8859_002d1-Characters.html#index-condition_002dtype_003abad_002drange_002dargument-760")
	("condition-type:bad-range-argument" "Integer-Conversions-of-Bit-Strings.html#index-condition_002dtype_003abad_002drange_002dargument-1415")
	("condition-type:bad-range-argument" "Numerical-operations.html#index-condition_002dtype_003abad_002drange_002dargument-593")
	("condition-type:bad-range-argument" "Taxonomy.html#index-condition_002dtype_003abad_002drange_002dargument-2947")
	("condition-type:breakpoint" "Error-System.html#index-condition_002dtype_003abreakpoint-2765")
	("condition-type:breakpoint" "Taxonomy.html#index-condition_002dtype_003abreakpoint-2975")
	("condition-type:control-error" "Taxonomy.html#index-condition_002dtype_003acontrol_002derror-2968")
	("condition-type:datum-out-of-range" "Taxonomy.html#index-condition_002dtype_003adatum_002dout_002dof_002drange-2945")
	("condition-type:derived-file-error" "Taxonomy.html#index-condition_002dtype_003aderived_002dfile_002derror-2953")
	("condition-type:derived-port-error" "Taxonomy.html#index-condition_002dtype_003aderived_002dport_002derror-2956")
	("condition-type:divide-by-zero" "Taxonomy.html#index-condition_002dtype_003adivide_002dby_002dzero-2962")
	("condition-type:error" "Condition-Types.html#index-condition_002dtype_003aerror-2928")
	("condition-type:error" "Taxonomy.html#index-condition_002dtype_003aerror-2936")
	("condition-type:error" "Condition-State.html#index-condition_002dtype_003aerror-2910")
	("condition-type:error" "Condition-Handling.html#index-condition_002dtype_003aerror-2809")
	("condition-type:extra-applicable-methods" "Generic-Procedures.html#index-condition_002dtype_003aextra_002dapplicable_002dmethods-1886")
	("condition-type:file-error" "Taxonomy.html#index-condition_002dtype_003afile_002derror-2950")
	("condition-type:file-operation-error" "File-Ports.html#index-condition_002dtype_003afile_002doperation_002derror-2015")
	("condition-type:file-operation-error" "File-Manipulation.html#index-condition_002dtype_003afile_002doperation_002derror-2604")
	("condition-type:file-operation-error" "File-Ports.html#index-condition_002dtype_003afile_002doperation_002derror-2012")
	("condition-type:file-operation-error" "Miscellaneous-Pathnames.html#index-condition_002dtype_003afile_002doperation_002derror-2563")
	("condition-type:file-operation-error" "File-Ports.html#index-condition_002dtype_003afile_002doperation_002derror-2019")
	("condition-type:file-operation-error" "File-Manipulation.html#index-condition_002dtype_003afile_002doperation_002derror-2580")
	("condition-type:file-operation-error" "Taxonomy.html#index-condition_002dtype_003afile_002doperation_002derror-2951")
	("condition-type:floating-point-overflow" "Taxonomy.html#index-condition_002dtype_003afloating_002dpoint_002doverflow-2964")
	("condition-type:floating-point-underflow" "Taxonomy.html#index-condition_002dtype_003afloating_002dpoint_002dunderflow-2965")
	("condition-type:illegal-datum" "Taxonomy.html#index-condition_002dtype_003aillegal_002ddatum-2938")
	("condition-type:inapplicable-object" "Taxonomy.html#index-condition_002dtype_003ainapplicable_002dobject-2949")
	("condition-type:macro-binding" "Environment-Operations.html#index-condition_002dtype_003amacro_002dbinding-1909")
	("condition-type:no-applicable-methods" "Generic-Procedures.html#index-condition_002dtype_003ano_002dapplicable_002dmethods-1885")
	("condition-type:no-such-restart" "Taxonomy.html#index-condition_002dtype_003ano_002dsuch_002drestart-2969")
	("condition-type:no-such-restart" "Invoking-Standard-Restart-Code.html#index-condition_002dtype_003ano_002dsuch_002drestart-2859")
	("condition-type:not-loading" "Taxonomy.html#index-condition_002dtype_003anot_002dloading-2971")
	("condition-type:port-error" "Taxonomy.html#index-condition_002dtype_003aport_002derror-2955")
	("condition-type:primitive-procedure-error" "Taxonomy.html#index-condition_002dtype_003aprimitive_002dprocedure_002derror-2966")
	("condition-type:serious-condition" "Error-System.html#index-condition_002dtype_003aserious_002dcondition-2766")
	("condition-type:serious-condition" "Taxonomy.html#index-condition_002dtype_003aserious_002dcondition-2935")
	("condition-type:simple-condition" "Taxonomy.html#index-condition_002dtype_003asimple_002dcondition-2974")
	("condition-type:simple-condition" "Error-System.html#index-condition_002dtype_003asimple_002dcondition-2763")
	("condition-type:simple-error" "Taxonomy.html#index-condition_002dtype_003asimple_002derror-2937")
	("condition-type:simple-error" "Condition-Signalling.html#index-condition_002dtype_003asimple_002derror-2782")
	("condition-type:simple-warning" "Taxonomy.html#index-condition_002dtype_003asimple_002dwarning-2973")
	("condition-type:simple-warning" "Condition-Signalling.html#index-condition_002dtype_003asimple_002dwarning-2786")
	("condition-type:subprocess-abnormal-termination" "Subprocess-Conditions.html#index-condition_002dtype_003asubprocess_002dabnormal_002dtermination-2723")
	("condition-type:subprocess-signalled" "Subprocess-Conditions.html#index-condition_002dtype_003asubprocess_002dsignalled-2721")
	("condition-type:subprocess-stopped" "Subprocess-Conditions.html#index-condition_002dtype_003asubprocess_002dstopped-2722")
	("condition-type:system-call-error" "Taxonomy.html#index-condition_002dtype_003asystem_002dcall_002derror-2967")
	("condition-type:unassigned-variable" "Environment-Operations.html#index-condition_002dtype_003aunassigned_002dvariable-1905")
	("condition-type:unassigned-variable" "Taxonomy.html#index-condition_002dtype_003aunassigned_002dvariable-2960")
	("condition-type:unassigned-variable" "Variable-Bindings.html#index-condition_002dtype_003aunassigned_002dvariable-66")
	("condition-type:unbound-variable" "Environment-Concepts.html#index-condition_002dtype_003aunbound_002dvariable-70")
	("condition-type:unbound-variable" "Dynamic-Binding.html#index-condition_002dtype_003aunbound_002dvariable-230")
	("condition-type:unbound-variable" "Taxonomy.html#index-condition_002dtype_003aunbound_002dvariable-2959")
	("condition-type:variable-error" "Taxonomy.html#index-condition_002dtype_003avariable_002derror-2958")
	("condition-type:warning" "Taxonomy.html#index-condition_002dtype_003awarning-2972")
	("condition-type:warning" "Error-System.html#index-condition_002dtype_003awarning-2764")
	("condition-type:wrong-number-of-arguments" "Lambda-Expressions.html#index-condition_002dtype_003awrong_002dnumber_002dof_002darguments-200")
	("condition-type:wrong-number-of-arguments" "Arity.html#index-condition_002dtype_003awrong_002dnumber_002dof_002darguments-1830")
	("condition-type:wrong-number-of-arguments" "Lambda-Expressions.html#index-condition_002dtype_003awrong_002dnumber_002dof_002darguments-196")
	("condition-type:wrong-number-of-arguments" "Taxonomy.html#index-condition_002dtype_003awrong_002dnumber_002dof_002darguments-2943")
	("condition-type:wrong-type-argument" "Entry-Format.html#index-condition_002dtype_003awrong_002dtype_002dargument-54")
	("condition-type:wrong-type-argument" "Taxonomy.html#index-condition_002dtype_003awrong_002dtype_002dargument-2941")
	("condition-type:wrong-type-argument" "Ports.html#index-condition_002dtype_003awrong_002dtype_002dargument-1974")
	("condition-type:wrong-type-datum" "Taxonomy.html#index-condition_002dtype_003awrong_002dtype_002ddatum-2939")
	("condition-type?" "Condition-Types.html#index-condition_002dtype_003f-2934")
	("condition/continuation" "Condition-State.html#index-condition_002fcontinuation-2913")
	("condition/error?" "Condition-State.html#index-condition_002ferror_003f-2909")
	("condition/report-string" "Simple-Condition-Instance-Operations.html#index-condition_002freport_002dstring-2921")
	("condition/restarts" "Generating-Operations-on-Conditions.html#index-condition_002frestarts-2898")
	("condition/restarts" "Simple-Condition-Instance-Operations.html#index-condition_002frestarts-2916")
	("condition/restarts" "Condition-State.html#index-condition_002frestarts-2912")
	("condition/type" "Condition-State.html#index-condition_002ftype-2908")
	("condition?" "Condition-State.html#index-condition_003f-2907")
	("conjugate" "Numerical-operations.html#index-conjugate-590")
	("cons" "Pairs.html#index-cons-1120")
	("cons*" "Construction-of-Lists.html#index-cons_002a-1166")
	("cons-stream" "Streams.html#index-cons_002dstream-1535")
	("console-i/o-port" "Ports.html#index-console_002di_002fo_002dport-1993")
	("console-input-port" "Ports.html#index-console_002dinput_002dport-1977")
	("console-output-port" "Ports.html#index-console_002doutput_002dport-1979")
	("constructor" "Structure-Definitions.html#index-constructor-354")
	("continuation?" "Continuations.html#index-continuation_003f-1847")
	("continue" "Restarts.html#index-continue-2846")
	("continue" "Invoking-Standard-Restart-Code.html#index-continue-2860")
	("copier" "Structure-Definitions.html#index-copier-351")
	("copy-area on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-copy_002darea-on-win32_002dgraphics_002ddevice-3116")
	("copy-area on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-copy_002darea-on-x_002dgraphics_002ddevice-3075")
	("copy-bitmap" "DIB-procedures.html#index-copy_002dbitmap-3176")
	("copy-file" "File-Manipulation.html#index-copy_002dfile-2585")
	("cos" "Numerical-operations.html#index-cos-574")
	("create-dib" "DIB-procedures.html#index-create_002ddib-3177")
	("create-image on graphics-device" "Images.html#index-create_002dimage-on-graphics_002ddevice-3027")
	("crop-bitmap" "DIB-procedures.html#index-crop_002dbitmap-3178")
	("current-file-time" "File-Manipulation.html#index-current_002dfile_002dtime-2642")
	("current-input-port" "File-Ports.html#index-current_002dinput_002dport-2033")
	("current-input-port" "Ports.html#index-current_002dinput_002dport-1976")
	("current-output-port" "Ports.html#index-current_002doutput_002dport-1978")
	("current-output-port" "File-Ports.html#index-current_002doutput_002dport-2034")
	("current-output-port" "String-Ports.html#index-current_002doutput_002dport-2053")
	("current-parser-macros" "Parser_002dlanguage-Macros.html#index-current_002dparser_002dmacros-2314")
	("day-of-week/long-string" "External-Representation-of-Time.html#index-day_002dof_002dweek_002flong_002dstring-2703")
	("day-of-week/short-string" "External-Representation-of-Time.html#index-day_002dof_002dweek_002fshort_002dstring-2704")
	("debug" "Prompting.html#index-debug-2144")
	("decoded-time->file-time" "Time_002dFormat-Conversion.html#index-decoded_002dtime_002d_003efile_002dtime-2691")
	("decoded-time->string" "Time_002dFormat-Conversion.html#index-decoded_002dtime_002d_003estring-2692")
	("decoded-time->universal-time" "Time_002dFormat-Conversion.html#index-decoded_002dtime_002d_003euniversal_002dtime-2690")
	("decoded-time/date-string" "External-Representation-of-Time.html#index-decoded_002dtime_002fdate_002dstring-2701")
	("decoded-time/day" "Decoded-Time.html#index-decoded_002dtime_002fday-2677")
	("decoded-time/day-of-week" "Decoded-Time.html#index-decoded_002dtime_002fday_002dof_002dweek-2680")
	("decoded-time/daylight-savings-time?" "Decoded-Time.html#index-decoded_002dtime_002fdaylight_002dsavings_002dtime_003f-2681")
	("decoded-time/hour" "Decoded-Time.html#index-decoded_002dtime_002fhour-2676")
	("decoded-time/minute" "Decoded-Time.html#index-decoded_002dtime_002fminute-2675")
	("decoded-time/month" "Decoded-Time.html#index-decoded_002dtime_002fmonth-2678")
	("decoded-time/second" "Decoded-Time.html#index-decoded_002dtime_002fsecond-2674")
	("decoded-time/time-string" "External-Representation-of-Time.html#index-decoded_002dtime_002ftime_002dstring-2702")
	("decoded-time/year" "Decoded-Time.html#index-decoded_002dtime_002fyear-2679")
	("decoded-time/zone" "Decoded-Time.html#index-decoded_002dtime_002fzone-2682")
	("default-object?" "Lambda-Expressions.html#index-default_002dobject_003f-201")
	("define" "Environment-Concepts.html#index-define-81")
	("define" "Environment-Variables.html#index-define-1930")
	("define" "Internal-Definitions.html#index-define-265")
	("define" "Definitions.html#index-define-236")
	("define" "Sequencing.html#index-define-326")
	("define-*matcher-expander" "Parser_002dlanguage-Macros.html#index-define_002d_002amatcher_002dexpander-2309")
	("define-*matcher-macro" "Parser_002dlanguage-Macros.html#index-define_002d_002amatcher_002dmacro-2307")
	("define-*parser-expander" "Parser_002dlanguage-Macros.html#index-define_002d_002aparser_002dexpander-2310")
	("define-*parser-macro" "Parser_002dlanguage-Macros.html#index-define_002d_002aparser_002dmacro-2308")
	("define-color on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-define_002dcolor-on-win32_002dgraphics_002ddevice-3098")
	("define-record-type" "define_002drecord_002dtype-_0028SRFI-9_0029.html#index-define_002drecord_002dtype-414")
	("define-similar-windows-type" "Windows-Types.html#index-define_002dsimilar_002dwindows_002dtype-3125")
	("define-structure" "Structure-Definitions.html#index-define_002dstructure-345")
	("define-structure" "Records.html#index-define_002dstructure-1497")
	("define-syntax" "Syntactic-Binding-Constructs.html#index-define_002dsyntax-376")
	("define-windows-type" "Windows-Types.html#index-define_002dwindows_002dtype-3124")
	("del-assoc" "Association-Lists.html#index-del_002dassoc-1603")
	("del-assoc!" "Association-Lists.html#index-del_002dassoc_0021-1610")
	("del-assq" "Association-Lists.html#index-del_002dassq-1601")
	("del-assq!" "Association-Lists.html#index-del_002dassq_0021-1608")
	("del-assv" "Association-Lists.html#index-del_002dassv-1602")
	("del-assv!" "Association-Lists.html#index-del_002dassv_0021-1609")
	("delay" "Promises.html#index-delay-1512")
	("delay" "Lexical-Binding.html#index-delay-222")
	("delete" "Filtering-Lists.html#index-delete-1236")
	("delete!" "Filtering-Lists.html#index-delete_0021-1242")
	("delete-association-procedure" "Association-Lists.html#index-delete_002dassociation_002dprocedure-1614")
	("delete-dib" "DIB-procedures.html#index-delete_002ddib-3173")
	("delete-directory" "File-Manipulation.html#index-delete_002ddirectory-2601")
	("delete-file" "File-Manipulation.html#index-delete_002dfile-2590")
	("delete-file-no-errors" "File-Manipulation.html#index-delete_002dfile_002dno_002derrors-2592")
	("delete-matching-items" "Filtering-Lists.html#index-delete_002dmatching_002ditems-1226")
	("delete-matching-items!" "Filtering-Lists.html#index-delete_002dmatching_002ditems_0021-1233")
	("delete-member-procedure" "Filtering-Lists.html#index-delete_002dmember_002dprocedure-1246")
	("delq" "Filtering-Lists.html#index-delq-1234")
	("delq!" "Filtering-Lists.html#index-delq_0021-1240")
	("delv" "Filtering-Lists.html#index-delv-1235")
	("delv!" "Filtering-Lists.html#index-delv_0021-1241")
	("denominator" "Numerical-operations.html#index-denominator-556")
	("dib" "Device-Independent-Bitmap-Utilities.html#index-dib-3167")
	("dib-blt" "DIB-procedures.html#index-dib_002dblt-3172")
	("dib-from-bitmap" "DIB-procedures.html#index-dib_002dfrom_002dbitmap-3171")
	("dib-height" "DIB-procedures.html#index-dib_002dheight-3174")
	("dib-set-pixels-unaligned" "DIB-procedures.html#index-dib_002dset_002dpixels_002dunaligned-3179")
	("dib-width" "DIB-procedures.html#index-dib_002dwidth-3175")
	("digit->char" "Miscellaneous-Character-Operations.html#index-digit_002d_003echar-734")
	("directory-namestring" "Operations-on-Pathnames.html#index-directory_002dnamestring-2539")
	("directory-pathname" "Operations-on-Pathnames.html#index-directory_002dpathname-2544")
	("directory-pathname-as-file" "Operations-on-Pathnames.html#index-directory_002dpathname_002das_002dfile-2547")
	("directory-pathname?" "Operations-on-Pathnames.html#index-directory_002dpathname_003f-2530")
	("directory-read" "Directory-Reader.html#index-directory_002dread-2661")
	("discard-chars on input port" "Input-Port-Operations.html#index-discard_002dchars-on-input-port-2179")
	("discard-matched" "_002aMatcher.html#index-discard_002dmatched-2282")
	("discard-matched" "_002aParser.html#index-discard_002dmatched-2296")
	("discard-parser-buffer-head!" "Parser-Buffers.html#index-discard_002dparser_002dbuffer_002dhead_0021-2244")
	("discretionary-flush-output" "Output-Procedures.html#index-discretionary_002dflush_002doutput-2085")
	("discretionary-flush-output on output port" "Output-Port-Operations.html#index-discretionary_002dflush_002doutput-on-output-port-2200")
	("dispatch-tag" "Dispatch-Tags.html#index-dispatch_002dtag-1895")
	("dispatch-tag?" "Dispatch-Tags.html#index-dispatch_002dtag_003f-1899")
	("display" "Output-Procedures.html#index-display-2094")
	("display" "Error-Messages.html#index-display-2797")
	("display" "Ports.html#index-display-1964")
	("do" "Iteration.html#index-do-342")
	("do" "Environment-Concepts.html#index-do-80")
	("do" "Sequencing.html#index-do-327")
	("dotted-list?" "Selecting-List-Components.html#index-dotted_002dlist_003f-1188")
	("draw-arc" "Custom-Operations-on-X-Graphics-Devices.html#index-draw_002darc-3057")
	("draw-arc on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-draw_002darc-on-x_002dgraphics_002ddevice-3053")
	("draw-circle" "Custom-Operations-on-X-Graphics-Devices.html#index-draw_002dcircle-3063")
	("draw-circle on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-draw_002dcircle-on-x_002dgraphics_002ddevice-3058")
	("draw-ellipse on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-draw_002dellipse-on-win32_002dgraphics_002ddevice-3100")
	("draw-image on graphics-device" "Images.html#index-draw_002dimage-on-graphics_002ddevice-3028")
	("draw-subimage on graphics-device" "Images.html#index-draw_002dsubimage-on-graphics_002ddevice-3029")
	("dynamic-wind" "Continuations.html#index-dynamic_002dwind-1852")
	("eighth" "Selecting-List-Components.html#index-eighth-1206")
	("else" "Conditionals.html#index-else-310")
	("else" "Entry-Format.html#index-else-42")
	("encapsulate" "_002aParser.html#index-encapsulate-2303")
	("end-of-input" "_002aMatcher.html#index-end_002dof_002dinput-2281")
	("enough-namestring" "Operations-on-Pathnames.html#index-enough_002dnamestring-2541")
	("enough-pathname" "Operations-on-Pathnames.html#index-enough_002dpathname-2545")
	("entity-extra" "Application-Hooks.html#index-entity_002dextra-1874")
	("entity-procedure" "Application-Hooks.html#index-entity_002dprocedure-1872")
	("entity?" "Application-Hooks.html#index-entity_003f-1870")
	("enumerate-graphics-types" "Opening-and-Closing-of-Graphics-Devices.html#index-enumerate_002dgraphics_002dtypes-2979")
	("environment" "Subprocess-Options.html#index-environment-2731")
	("environment-assign!" "Environment-Operations.html#index-environment_002dassign_0021-1923")
	("environment-assignable?" "Environment-Operations.html#index-environment_002dassignable_003f-1922")
	("environment-assigned?" "Environment-Operations.html#index-environment_002dassigned_003f-1919")
	("environment-bindings" "Environment-Operations.html#index-environment_002dbindings-1916")
	("environment-bound-names" "Environment-Operations.html#index-environment_002dbound_002dnames-1914")
	("environment-bound?" "Environment-Operations.html#index-environment_002dbound_003f-1918")
	("environment-definable?" "Environment-Operations.html#index-environment_002ddefinable_003f-1924")
	("environment-define" "Environment-Operations.html#index-environment_002ddefine-1925")
	("environment-define-macro" "Environment-Operations.html#index-environment_002ddefine_002dmacro-1926")
	("environment-has-parent?" "Environment-Operations.html#index-environment_002dhas_002dparent_003f-1912")
	("environment-lookup" "Environment-Operations.html#index-environment_002dlookup-1920")
	("environment-lookup-macro" "Environment-Operations.html#index-environment_002dlookup_002dmacro-1921")
	("environment-macro-names" "Environment-Operations.html#index-environment_002dmacro_002dnames-1915")
	("environment-parent" "Environment-Operations.html#index-environment_002dparent-1913")
	("environment-reference-type" "Environment-Operations.html#index-environment_002dreference_002dtype-1917")
	("environment?" "Environment-Operations.html#index-environment_003f-1910")
	("eof-object?" "Input-Procedures.html#index-eof_002dobject_003f-2067")
	("eof-object?" "Constructors-and-Accessors-for-Ports.html#index-eof_002dobject_003f-2172")
	("eof? on input port" "Input-Port-Operations.html#index-eof_003f-on-input-port-2188")
	("ephemeron-broken?" "Ephemerons.html#index-ephemeron_002dbroken_003f-1578")
	("ephemeron-datum" "Ephemerons.html#index-ephemeron_002ddatum-1580")
	("ephemeron-key" "Ephemerons.html#index-ephemeron_002dkey-1579")
	("ephemeron?" "Ephemerons.html#index-ephemeron_003f-1574")
	("epoch" "Universal-Time.html#index-epoch-2670")
	("eq-hash" "Address-Hashing.html#index-eq_002dhash-1700")
	("eq-hash-mod" "Address-Hashing.html#index-eq_002dhash_002dmod-1703")
	("eq-hash-mod" "Construction-of-Hash-Tables.html#index-eq_002dhash_002dmod-1668")
	("eq?" "Symbols.html#index-eq_003f-1478")
	("eq?" "The-Association-Table.html#index-eq_003f-1637")
	("eq?" "Symbols.html#index-eq_003f-1454")
	("eq?" "Association-Lists.html#index-eq_003f-1605")
	("eq?" "Object-Hashing.html#index-eq_003f-1715")
	("eq?" "Equivalence-Predicates.html#index-eq_003f-419")
	("eq?" "Association-Lists.html#index-eq_003f-1597")
	("eq?" "The-Named-Restart-Abstraction.html#index-eq_003f-2883")
	("eq?" "Construction-of-Hash-Tables.html#index-eq_003f-1649")
	("eq?" "Equivalence-Predicates.html#index-eq_003f-431")
	("eq?" "Filtering-Lists.html#index-eq_003f-1243")
	("eq?" "Object-Hashing.html#index-eq_003f-1709")
	("eq?" "Construction-of-Hash-Tables.html#index-eq_003f-1651")
	("eq?" "Filtering-Lists.html#index-eq_003f-1237")
	("eq?" "Searching-Lists.html#index-eq_003f-1262")
	("eq?" "Construction-of-Hash-Tables.html#index-eq_003f-1669")
	("equal-hash" "Address-Hashing.html#index-equal_002dhash-1702")
	("equal-hash-mod" "Address-Hashing.html#index-equal_002dhash_002dmod-1705")
	("equal-hash-mod" "Construction-of-Hash-Tables.html#index-equal_002dhash_002dmod-1670")
	("equal?" "Association-Lists.html#index-equal_003f-1599")
	("equal?" "Construction-of-Hash-Tables.html#index-equal_003f-1661")
	("equal?" "Equivalence-Predicates.html#index-equal_003f-432")
	("equal?" "Quoting.html#index-equal_003f-287")
	("equal?" "Association-Lists.html#index-equal_003f-1613")
	("equal?" "Equivalence-Predicates.html#index-equal_003f-421")
	("equal?" "Filtering-Lists.html#index-equal_003f-1239")
	("equal?" "Construction-of-Hash-Tables.html#index-equal_003f-1671")
	("equal?" "Searching-Lists.html#index-equal_003f-1264")
	("equal?" "Association-Lists.html#index-equal_003f-1607")
	("equal?" "Filtering-Lists.html#index-equal_003f-1245")
	("eqv-hash" "Address-Hashing.html#index-eqv_002dhash-1701")
	("eqv-hash-mod" "Address-Hashing.html#index-eqv_002dhash_002dmod-1704")
	("eqv?" "Modification-of-Strings.html#index-eqv_003f-1060")
	("eqv?" "Construction-of-Hash-Tables.html#index-eqv_003f-1659")
	("eqv?" "Filtering-Lists.html#index-eqv_003f-1244")
	("eqv?" "Construction-of-Hash-Tables.html#index-eqv_003f-1655")
	("eqv?" "Searching-Lists.html#index-eqv_003f-1263")
	("eqv?" "Filtering-Lists.html#index-eqv_003f-1238")
	("eqv?" "Equivalence-Predicates.html#index-eqv_003f-422")
	("eqv?" "Association-Lists.html#index-eqv_003f-1598")
	("eqv?" "Pairs.html#index-eqv_003f-1122")
	("eqv?" "Conditionals.html#index-eqv_003f-318")
	("eqv?" "Storage-Model.html#index-eqv_003f-114")
	("eqv?" "Association-Lists.html#index-eqv_003f-1612")
	("er-macro-transformer" "Explicit-Renaming.html#index-er_002dmacro_002dtransformer-401")
	("error" "Condition-Signalling.html#index-error-2777")
	("error" "Errors.html#index-error-25")
	("error" "Condition-Handling.html#index-error-2818")
	("error" "Error-System.html#index-error-2759")
	("error" "Condition-Signalling.html#index-error-2784")
	("error-irritant/noise" "Error-Messages.html#index-error_002dirritant_002fnoise-2800")
	("error:bad-range-argument" "Taxonomy.html#index-error_003abad_002drange_002dargument-2948")
	("error:datum-out-of-range" "Taxonomy.html#index-error_003adatum_002dout_002dof_002drange-2946")
	("error:derived-file" "Taxonomy.html#index-error_003aderived_002dfile-2954")
	("error:derived-port" "Taxonomy.html#index-error_003aderived_002dport-2957")
	("error:divide-by-zero" "Taxonomy.html#index-error_003adivide_002dby_002dzero-2963")
	("error:file-operation-error" "Taxonomy.html#index-error_003afile_002doperation_002derror-2952")
	("error:no-such-restart" "Taxonomy.html#index-error_003ano_002dsuch_002drestart-2970")
	("error:wrong-number-of-arguments" "Taxonomy.html#index-error_003awrong_002dnumber_002dof_002darguments-2944")
	("error:wrong-type-argument" "Taxonomy.html#index-error_003awrong_002dtype_002dargument-2942")
	("error:wrong-type-datum" "Taxonomy.html#index-error_003awrong_002dtype_002ddatum-2940")
	("eval" "Environment-Operations.html#index-eval-1927")
	("even?" "Numerical-operations.html#index-even_003f-500")
	("every" "Reduction-of-Lists.html#index-every-1285")
	("exact->inexact" "Numerical-operations.html#index-exact_002d_003einexact-591")
	("exact-integer?" "Numerical-operations.html#index-exact_002dinteger_003f-485")
	("exact-nonnegative-integer?" "Numerical-operations.html#index-exact_002dnonnegative_002dinteger_003f-486")
	("exact-rational?" "Numerical-operations.html#index-exact_002drational_003f-487")
	("exact?" "Numerical-operations.html#index-exact_003f-483")
	("except-last-pair" "Cutting-and-Pasting-Lists.html#index-except_002dlast_002dpair-1218")
	("except-last-pair!" "Cutting-and-Pasting-Lists.html#index-except_002dlast_002dpair_0021-1219")
	("exp" "Numerical-operations.html#index-exp-571")
	("expt" "Numerical-operations.html#index-expt-583")
	("extend-top-level-environment" "Top_002dlevel-Environments.html#index-extend_002dtop_002dlevel_002denvironment-1946")
	("false" "Booleans.html#index-false-1433")
	("false?" "Booleans.html#index-false_003f-1438")
	("fifth" "Selecting-List-Components.html#index-fifth-1203")
	("file-access" "File-Manipulation.html#index-file_002daccess-2621")
	("file-access-time" "File-Manipulation.html#index-file_002daccess_002dtime-2637")
	("file-access-time-direct" "File-Manipulation.html#index-file_002daccess_002dtime_002ddirect-2639")
	("file-access-time-indirect" "File-Manipulation.html#index-file_002daccess_002dtime_002dindirect-2640")
	("file-attributes" "File-Manipulation.html#index-file_002dattributes-2645")
	("file-attributes-direct" "File-Manipulation.html#index-file_002dattributes_002ddirect-2647")
	("file-attributes-indirect" "File-Manipulation.html#index-file_002dattributes_002dindirect-2648")
	("file-attributes/access-time" "File-Manipulation.html#index-file_002dattributes_002faccess_002dtime-2650")
	("file-attributes/change-time" "File-Manipulation.html#index-file_002dattributes_002fchange_002dtime-2652")
	("file-attributes/gid" "File-Manipulation.html#index-file_002dattributes_002fgid-2657")
	("file-attributes/inode-number" "File-Manipulation.html#index-file_002dattributes_002finode_002dnumber-2658")
	("file-attributes/length" "File-Manipulation.html#index-file_002dattributes_002flength-2653")
	("file-attributes/mode-string" "File-Manipulation.html#index-file_002dattributes_002fmode_002dstring-2654")
	("file-attributes/modes" "File-Manipulation.html#index-file_002dattributes_002fmodes-2659")
	("file-attributes/modification-time" "File-Manipulation.html#index-file_002dattributes_002fmodification_002dtime-2651")
	("file-attributes/n-links" "File-Manipulation.html#index-file_002dattributes_002fn_002dlinks-2655")
	("file-attributes/type" "File-Manipulation.html#index-file_002dattributes_002ftype-2649")
	("file-attributes/uid" "File-Manipulation.html#index-file_002dattributes_002fuid-2656")
	("file-directory?" "File-Manipulation.html#index-file_002ddirectory_003f-2608")
	("file-eq?" "File-Manipulation.html#index-file_002deq_003f-2622")
	("file-executable?" "File-Manipulation.html#index-file_002dexecutable_003f-2620")
	("file-exists-direct?" "File-Manipulation.html#index-file_002dexists_002ddirect_003f-2582")
	("file-exists-indirect?" "File-Manipulation.html#index-file_002dexists_002dindirect_003f-2583")
	("file-exists?" "File-Manipulation.html#index-file_002dexists_003f-2581")
	("file-length" "File-Manipulation.html#index-file_002dlength-2644")
	("file-modes" "File-Manipulation.html#index-file_002dmodes-2623")
	("file-modification-time" "File-Manipulation.html#index-file_002dmodification_002dtime-2633")
	("file-modification-time-direct" "File-Manipulation.html#index-file_002dmodification_002dtime_002ddirect-2635")
	("file-modification-time-indirect" "File-Manipulation.html#index-file_002dmodification_002dtime_002dindirect-2636")
	("file-namestring" "Operations-on-Pathnames.html#index-file_002dnamestring-2538")
	("file-pathname" "Operations-on-Pathnames.html#index-file_002dpathname-2543")
	("file-readable?" "File-Manipulation.html#index-file_002dreadable_003f-2618")
	("file-regular?" "File-Manipulation.html#index-file_002dregular_003f-2610")
	("file-symbolic-link?" "File-Manipulation.html#index-file_002dsymbolic_002dlink_003f-2613")
	("file-time->global-decoded-time" "Time_002dFormat-Conversion.html#index-file_002dtime_002d_003eglobal_002ddecoded_002dtime-2695")
	("file-time->global-time-string" "Time_002dFormat-Conversion.html#index-file_002dtime_002d_003eglobal_002dtime_002dstring-2697")
	("file-time->local-decoded-time" "Time_002dFormat-Conversion.html#index-file_002dtime_002d_003elocal_002ddecoded_002dtime-2694")
	("file-time->local-time-string" "Time_002dFormat-Conversion.html#index-file_002dtime_002d_003elocal_002dtime_002dstring-2696")
	("file-time->universal-time" "Time_002dFormat-Conversion.html#index-file_002dtime_002d_003euniversal_002dtime-2693")
	("file-touch" "File-Manipulation.html#index-file_002dtouch-2643")
	("file-type-direct" "File-Manipulation.html#index-file_002dtype_002ddirect-2615")
	("file-type-indirect" "File-Manipulation.html#index-file_002dtype_002dindirect-2616")
	("file-writeable?" "File-Manipulation.html#index-file_002dwriteable_003f-2619")
	("fill-circle" "Custom-Operations-on-X-Graphics-Devices.html#index-fill_002dcircle-3064")
	("fill-circle on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-fill_002dcircle-on-x_002dgraphics_002ddevice-3059")
	("fill-polygon" "Custom-Operations-for-Win32-Graphics.html#index-fill_002dpolygon-3106")
	("fill-polygon on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-fill_002dpolygon-on-win32_002dgraphics_002ddevice-3105")
	("filter" "Filtering-Lists.html#index-filter-1222")
	("filter!" "Filtering-Lists.html#index-filter_0021-1229")
	("find" "Searching-Lists.html#index-find-1254")
	("find-color on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-find_002dcolor-on-win32_002dgraphics_002ddevice-3099")
	("find-matching-item" "Searching-Lists.html#index-find_002dmatching_002ditem-1255")
	("find-module" "Windows-Foreign-Procedures.html#index-find_002dmodule-3153")
	("find-restart" "Finding-and-Invoking-General-Restart-Code.html#index-find_002drestart-2872")
	("find-restart" "Restarts.html#index-find_002drestart-2842")
	("find-tail" "Searching-Lists.html#index-find_002dtail-1258")
	("first" "Selecting-List-Components.html#index-first-1199")
	("fix:*" "Fixnum-Operations.html#index-fix_003a_002a-613")
	("fix:+" "Fixnum-Operations.html#index-fix_003a_002b-611")
	("fix:-" "Fixnum-Operations.html#index-fix_003a_002d-612")
	("fix:-1+" "Fixnum-Operations.html#index-fix_003a_002d1_002b-618")
	("fix:1+" "Fixnum-Operations.html#index-fix_003a1_002b-617")
	("fix:<" "Fixnum-Operations.html#index-fix_003a_003c-603")
	("fix:<=" "Fixnum-Operations.html#index-fix_003a_003c_003d-605")
	("fix:=" "Fixnum-Operations.html#index-fix_003a_003d-602")
	("fix:>" "Fixnum-Operations.html#index-fix_003a_003e-604")
	("fix:>=" "Fixnum-Operations.html#index-fix_003a_003e_003d-606")
	("fix:and" "Fixnum-Operations.html#index-fix_003aand-626")
	("fix:andc" "Fixnum-Operations.html#index-fix_003aandc-627")
	("fix:divide" "Fixnum-Operations.html#index-fix_003adivide-619")
	("fix:fixnum?" "Fixnum-Operations.html#index-fix_003afixnum_003f-600")
	("fix:gcd" "Fixnum-Operations.html#index-fix_003agcd-616")
	("fix:lsh" "Fixnum-Operations.html#index-fix_003alsh-630")
	("fix:negative?" "Fixnum-Operations.html#index-fix_003anegative_003f-610")
	("fix:not" "Fixnum-Operations.html#index-fix_003anot-625")
	("fix:or" "Fixnum-Operations.html#index-fix_003aor-628")
	("fix:positive?" "Fixnum-Operations.html#index-fix_003apositive_003f-609")
	("fix:quotient" "Fixnum-Operations.html#index-fix_003aquotient-614")
	("fix:remainder" "Fixnum-Operations.html#index-fix_003aremainder-615")
	("fix:xor" "Fixnum-Operations.html#index-fix_003axor-629")
	("fix:zero?" "Fixnum-Operations.html#index-fix_003azero_003f-608")
	("flo:*" "Flonum-Operations.html#index-flo_003a_002a-643")
	("flo:+" "Flonum-Operations.html#index-flo_003a_002b-641")
	("flo:-" "Flonum-Operations.html#index-flo_003a_002d-642")
	("flo:/" "Flonum-Operations.html#index-flo_003a_002f-644")
	("flo:<" "Flonum-Operations.html#index-flo_003a_003c-635")
	("flo:=" "Flonum-Operations.html#index-flo_003a_003d-634")
	("flo:>" "Flonum-Operations.html#index-flo_003a_003e-636")
	("flo:abs" "Flonum-Operations.html#index-flo_003aabs-653")
	("flo:acos" "Flonum-Operations.html#index-flo_003aacos-660")
	("flo:asin" "Flonum-Operations.html#index-flo_003aasin-659")
	("flo:atan" "Flonum-Operations.html#index-flo_003aatan-661")
	("flo:atan2" "Flonum-Operations.html#index-flo_003aatan2-672")
	("flo:ceiling" "Flonum-Operations.html#index-flo_003aceiling-665")
	("flo:ceiling->exact" "Flonum-Operations.html#index-flo_003aceiling_002d_003eexact-669")
	("flo:cos" "Flonum-Operations.html#index-flo_003acos-657")
	("flo:exp" "Flonum-Operations.html#index-flo_003aexp-654")
	("flo:expt" "Flonum-Operations.html#index-flo_003aexpt-663")
	("flo:finite?" "Flonum-Operations.html#index-flo_003afinite_003f-645")
	("flo:flonum?" "Flonum-Operations.html#index-flo_003aflonum_003f-632")
	("flo:floor" "Flonum-Operations.html#index-flo_003afloor-664")
	("flo:floor->exact" "Flonum-Operations.html#index-flo_003afloor_002d_003eexact-668")
	("flo:log" "Flonum-Operations.html#index-flo_003alog-655")
	("flo:negate" "Flonum-Operations.html#index-flo_003anegate-652")
	("flo:negative?" "Flonum-Operations.html#index-flo_003anegative_003f-640")
	("flo:positive?" "Flonum-Operations.html#index-flo_003apositive_003f-639")
	("flo:random-unit" "Random-Numbers.html#index-flo_003arandom_002dunit-678")
	("flo:round" "Flonum-Operations.html#index-flo_003around-667")
	("flo:round->exact" "Flonum-Operations.html#index-flo_003around_002d_003eexact-671")
	("flo:sin" "Flonum-Operations.html#index-flo_003asin-656")
	("flo:sqrt" "Flonum-Operations.html#index-flo_003asqrt-662")
	("flo:tan" "Flonum-Operations.html#index-flo_003atan-658")
	("flo:truncate" "Flonum-Operations.html#index-flo_003atruncate-666")
	("flo:truncate->exact" "Flonum-Operations.html#index-flo_003atruncate_002d_003eexact-670")
	("flo:zero?" "Flonum-Operations.html#index-flo_003azero_003f-638")
	("flonum-parser-fast?" "Numerical-input-and-output.html#index-flonum_002dparser_002dfast_003f-596")
	("flonum-unparser-cutoff" "Numerical-input-and-output.html#index-flonum_002dunparser_002dcutoff-597")
	("floor" "Numerical-operations.html#index-floor-557")
	("floor->exact" "Numerical-operations.html#index-floor_002d_003eexact-561")
	("fluid-let" "Internal-Definitions.html#index-fluid_002dlet-264")
	("fluid-let" "Definitions.html#index-fluid_002dlet-246")
	("fluid-let" "Sequencing.html#index-fluid_002dlet-328")
	("fluid-let" "Dynamic-Binding.html#index-fluid_002dlet-223")
	("flush-output" "Output-Procedures.html#index-flush_002doutput-2101")
	("flush-output on output port" "Output-Port-Operations.html#index-flush_002doutput-on-output-port-2199")
	("fold-left" "Reduction-of-Lists.html#index-fold_002dleft-1282")
	("fold-right" "Reduction-of-Lists.html#index-fold_002dright-1281")
	("font-structure on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-font_002dstructure-on-x_002dgraphics_002ddevice-3076")
	("for-all?" "Reduction-of-Lists.html#index-for_002dall_003f-1286")
	("for-each" "Mapping-of-Lists.html#index-for_002deach-1277")
	("force" "Streams.html#index-force-1543")
	("force" "Promises.html#index-force-1520")
	("format" "Format.html#index-format-2122")
	("format-error-message" "Error-Messages.html#index-format_002derror_002dmessage-2799")
	("fourth" "Selecting-List-Components.html#index-fourth-1202")
	("fresh-line" "Output-Procedures.html#index-fresh_002dline-2099")
	("fresh-line on output port" "Output-Port-Operations.html#index-fresh_002dline-on-output-port-2198")
	("gcd" "Numerical-operations.html#index-gcd-551")
	("gdi32.dll" "Windows-Foreign-Procedures.html#index-gdi32_002edll-3156")
	("ge" "Initial-and-Current-Environments.html#index-ge-89")
	("ge" "REPL-Environment.html#index-ge-1935")
	("general-car-cdr" "Pairs.html#index-general_002dcar_002dcdr-1159")
	("generate-uninterned-symbol" "Symbols.html#index-generate_002duninterned_002dsymbol-1476")
	("generic-procedure-applicable?" "Generic-Procedures.html#index-generic_002dprocedure_002dapplicable_003f-1884")
	("generic-procedure-arity" "Generic-Procedures.html#index-generic_002dprocedure_002darity-1882")
	("generic-procedure-default-generator" "Method-Generators.html#index-generic_002dprocedure_002ddefault_002dgenerator-1891")
	("generic-procedure-generator-list" "Method-Generators.html#index-generic_002dprocedure_002dgenerator_002dlist-1890")
	("generic-procedure-name" "Generic-Procedures.html#index-generic_002dprocedure_002dname-1883")
	("generic-procedure?" "Generic-Procedures.html#index-generic_002dprocedure_003f-1880")
	("get-default on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-get_002ddefault-on-x_002dgraphics_002ddevice-3074")
	("get-host-by-address" "Miscellaneous-OS-Facilities.html#index-get_002dhost_002dby_002daddress-2751")
	("get-host-by-name" "Miscellaneous-OS-Facilities.html#index-get_002dhost_002dby_002dname-2750")
	("get-host-name" "Miscellaneous-OS-Facilities.html#index-get_002dhost_002dname-2753")
	("get-output-string" "String-Ports.html#index-get_002doutput_002dstring-2048")
	("get-parser-buffer-pointer" "Parser-Buffers.html#index-get_002dparser_002dbuffer_002dpointer-2241")
	("get-parser-buffer-tail" "Parser-Buffers.html#index-get_002dparser_002dbuffer_002dtail-2243")
	("get-universal-time" "Universal-Time.html#index-get_002duniversal_002dtime-2669")
	("global-decoded-time" "Decoded-Time.html#index-global_002ddecoded_002dtime-2672")
	("global-parser-macros" "Parser_002dlanguage-Macros.html#index-global_002dparser_002dmacros-2313")
	("graphics-bind-drawing-mode" "Characteristics-of-Graphics-Output.html#index-graphics_002dbind_002ddrawing_002dmode-3006")
	("graphics-bind-line-style" "Characteristics-of-Graphics-Output.html#index-graphics_002dbind_002dline_002dstyle-3007")
	("graphics-clear" "Custom-Operations-on-X-Graphics-Devices.html#index-graphics_002dclear-3052")
	("graphics-clear" "Drawing-Graphics.html#index-graphics_002dclear-2992")
	("graphics-close" "Opening-and-Closing-of-Graphics-Devices.html#index-graphics_002dclose-2981")
	("graphics-coordinate-limits" "Coordinates-for-Graphics.html#index-graphics_002dcoordinate_002dlimits-2989")
	("graphics-device-coordinate-limits" "Coordinates-for-Graphics.html#index-graphics_002ddevice_002dcoordinate_002dlimits-2988")
	("graphics-disable-buffering" "Buffering-of-Graphics-Output.html#index-graphics_002ddisable_002dbuffering-3013")
	("graphics-drag-cursor" "Drawing-Graphics.html#index-graphics_002ddrag_002dcursor-3000")
	("graphics-draw-line" "Drawing-Graphics.html#index-graphics_002ddraw_002dline-2995")
	("graphics-draw-point" "Drawing-Graphics.html#index-graphics_002ddraw_002dpoint-2993")
	("graphics-draw-text" "Drawing-Graphics.html#index-graphics_002ddraw_002dtext-2996")
	("graphics-enable-buffering" "Buffering-of-Graphics-Output.html#index-graphics_002denable_002dbuffering-3012")
	("graphics-erase-point" "Drawing-Graphics.html#index-graphics_002derase_002dpoint-2994")
	("graphics-flush" "Buffering-of-Graphics-Output.html#index-graphics_002dflush-3014")
	("graphics-move-cursor" "Drawing-Graphics.html#index-graphics_002dmove_002dcursor-2999")
	("graphics-operation" "Custom-Graphics-Operations.html#index-graphics_002doperation-3022")
	("graphics-reset-clip-rectangle" "Clipping-of-Graphics-Output.html#index-graphics_002dreset_002dclip_002drectangle-3019")
	("graphics-set-clip-rectangle" "Clipping-of-Graphics-Output.html#index-graphics_002dset_002dclip_002drectangle-3018")
	("graphics-set-coordinate-limits" "Coordinates-for-Graphics.html#index-graphics_002dset_002dcoordinate_002dlimits-2990")
	("graphics-set-drawing-mode" "Characteristics-of-Graphics-Output.html#index-graphics_002dset_002ddrawing_002dmode-3008")
	("graphics-set-line-style" "Characteristics-of-Graphics-Output.html#index-graphics_002dset_002dline_002dstyle-3009")
	("graphics-type-available?" "Opening-and-Closing-of-Graphics-Devices.html#index-graphics_002dtype_002davailable_003f-2978")
	("guarantee-dispatch-tag" "Dispatch-Tags.html#index-guarantee_002ddispatch_002dtag-1900")
	("guarantee-generic-procedure" "Generic-Procedures.html#index-guarantee_002dgeneric_002dprocedure-1881")
	("guarantee-i/o-port" "Ports.html#index-guarantee_002di_002fo_002dport-1973")
	("guarantee-input-port" "Ports.html#index-guarantee_002dinput_002dport-1971")
	("guarantee-output-port" "Ports.html#index-guarantee_002doutput_002dport-1972")
	("guarantee-port" "Ports.html#index-guarantee_002dport-1970")
	("guarantee-procedure-arity" "Arity.html#index-guarantee_002dprocedure_002darity-1827")
	("guarantee-procedure-of-arity" "Arity.html#index-guarantee_002dprocedure_002dof_002darity-1834")
	("guarantee-thunk" "Arity.html#index-guarantee_002dthunk-1836")
	("handle" "Windows-Types.html#index-handle-3140")
	("hard-link-file" "File-Manipulation.html#index-hard_002dlink_002dfile-2593")
	("hash" "Object-Hashing.html#index-hash-1708")
	("hash" "Custom-Output.html#index-hash-2137")
	("hash-table->alist" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002d_003ealist-1682")
	("hash-table/clean!" "Construction-of-Hash-Tables.html#index-hash_002dtable_002fclean_0021-1674")
	("hash-table/clear!" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002fclear_0021-1680")
	("hash-table/count" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002fcount-1681")
	("hash-table/datum-list" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002fdatum_002dlist-1684")
	("hash-table/for-each" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002ffor_002deach-1685")
	("hash-table/get" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002fget-1678")
	("hash-table/key-list" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002fkey_002dlist-1683")
	("hash-table/lookup" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002flookup-1686")
	("hash-table/make" "Object-Hashing.html#index-hash_002dtable_002fmake-1717")
	("hash-table/put!" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002fput_0021-1677")
	("hash-table/rehash-size" "Resizing-of-Hash-Tables.html#index-hash_002dtable_002frehash_002dsize-1695")
	("hash-table/rehash-threshold" "Resizing-of-Hash-Tables.html#index-hash_002dtable_002frehash_002dthreshold-1697")
	("hash-table/remove!" "Basic-Hash-Table-Operations.html#index-hash_002dtable_002fremove_0021-1679")
	("hash-table/size" "Resizing-of-Hash-Tables.html#index-hash_002dtable_002fsize-1694")
	("hash-table?" "Basic-Hash-Table-Operations.html#index-hash_002dtable_003f-1675")
	("hbitmap" "Windows-Types.html#index-hbitmap-3141")
	("hbrush" "Windows-Types.html#index-hbrush-3142")
	("hcursor" "Windows-Types.html#index-hcursor-3143")
	("hdc" "Windows-Types.html#index-hdc-3144")
	("hicon" "Windows-Types.html#index-hicon-3145")
	("hinstance" "Windows-Types.html#index-hinstance-3146")
	("hmenu" "Windows-Types.html#index-hmenu-3147")
	("host-address-any" "Miscellaneous-OS-Facilities.html#index-host_002daddress_002dany-2756")
	("host-address-loopback" "Miscellaneous-OS-Facilities.html#index-host_002daddress_002dloopback-2757")
	("host-namestring" "Operations-on-Pathnames.html#index-host_002dnamestring-2540")
	("host=?" "Miscellaneous-Pathnames.html#index-host_003d_003f-2555")
	("host?" "Miscellaneous-Pathnames.html#index-host_003f-2553")
	("hpalette" "Windows-Types.html#index-hpalette-3148")
	("hpen" "Windows-Types.html#index-hpen-3149")
	("hrgn" "Windows-Types.html#index-hrgn-3150")
	("hwnd" "Windows-Types.html#index-hwnd-3151")
	("i/o-port-type?" "Port-Types.html#index-i_002fo_002dport_002dtype_003f-2159")
	("i/o-port?" "Ports.html#index-i_002fo_002dport_003f-1969")
	("identifier=?" "SC-Identifiers.html#index-identifier_003d_003f-398")
	("identifier?" "SC-Identifiers.html#index-identifier_003f-397")
	("if" "Booleans.html#index-if-1427")
	("if" "Conditionals.html#index-if-305")
	("ignore-error" "Condition-Handling.html#index-ignore_002derror-2819")
	("ignore-errors" "Condition-Handling.html#index-ignore_002derrors-2807")
	("imag-part" "Numerical-operations.html#index-imag_002dpart-587")
	("image/destroy" "Images.html#index-image_002fdestroy-3031")
	("image/fill-from-byte-vector" "Images.html#index-image_002ffill_002dfrom_002dbyte_002dvector-3034")
	("image/height" "Images.html#index-image_002fheight-3032")
	("image/width" "Images.html#index-image_002fwidth-3033")
	("image?" "Images.html#index-image_003f-3030")
	("implemented-primitive-procedure?" "Primitive-Procedures.html#index-implemented_002dprimitive_002dprocedure_003f-1839")
	("inexact->exact" "Numerical-operations.html#index-inexact_002d_003eexact-592")
	("inexact->exact" "Exactness.html#index-inexact_002d_003eexact-438")
	("inexact?" "Numerical-operations.html#index-inexact_003f-484")
	("init-file-pathname" "Miscellaneous-Pathnames.html#index-init_002dfile_002dpathname-2557")
	("initial-offset" "Structure-Definitions.html#index-initial_002doffset-363")
	("input" "Subprocess-Options.html#index-input-2724")
	("input-buffer-size" "Subprocess-Options.html#index-input_002dbuffer_002dsize-2726")
	("input-buffer-size on input port" "Input-Port-Operations.html#index-input_002dbuffer_002dsize-on-input-port-2191")
	("input-line-translation" "Subprocess-Options.html#index-input_002dline_002dtranslation-2725")
	("input-port->parser-buffer" "Parser-Buffers.html#index-input_002dport_002d_003eparser_002dbuffer-2232")
	("input-port-type?" "Port-Types.html#index-input_002dport_002dtype_003f-2157")
	("input-port/char-ready?" "Input-Port-Operations.html#index-input_002dport_002fchar_002dready_003f-2184")
	("input-port/discard-chars" "Input-Port-Operations.html#index-input_002dport_002fdiscard_002dchars-2186")
	("input-port/peek-char" "Input-Port-Operations.html#index-input_002dport_002fpeek_002dchar-2183")
	("input-port/read-char" "Input-Port-Operations.html#index-input_002dport_002fread_002dchar-2182")
	("input-port/read-string" "Input-Port-Operations.html#index-input_002dport_002fread_002dstring-2185")
	("input-port/read-substring" "Input-Port-Operations.html#index-input_002dport_002fread_002dsubstring-2187")
	("input-port?" "Ports.html#index-input_002dport_003f-1967")
	("int" "Windows-Types.html#index-int-3130")
	("integer->char" "Internal-Representation-of-Characters.html#index-integer_002d_003echar-750")
	("integer-ceiling" "Numerical-operations.html#index-integer_002dceiling-542")
	("integer-divide" "Fixnum-Operations.html#index-integer_002ddivide-620")
	("integer-divide" "Numerical-operations.html#index-integer_002ddivide-546")
	("integer-divide-quotient" "Fixnum-Operations.html#index-integer_002ddivide_002dquotient-621")
	("integer-divide-quotient" "Numerical-operations.html#index-integer_002ddivide_002dquotient-547")
	("integer-divide-remainder" "Fixnum-Operations.html#index-integer_002ddivide_002dremainder-622")
	("integer-divide-remainder" "Numerical-operations.html#index-integer_002ddivide_002dremainder-548")
	("integer-floor" "Numerical-operations.html#index-integer_002dfloor-541")
	("integer-round" "Numerical-operations.html#index-integer_002dround-544")
	("integer-truncate" "Numerical-operations.html#index-integer_002dtruncate-543")
	("integer?" "Numerical-operations.html#index-integer_003f-479")
	("interaction-i/o-port" "Ports.html#index-interaction_002di_002fo_002dport-1982")
	("interaction-i/o-port" "Prompting.html#index-interaction_002di_002fo_002dport-2140")
	("intern" "Symbols.html#index-intern-1469")
	("intern-soft" "Symbols.html#index-intern_002dsoft-1472")
	("internal-time/seconds->ticks" "Machine-Time.html#index-internal_002dtime_002fseconds_002d_003eticks-2712")
	("internal-time/ticks->seconds" "Machine-Time.html#index-internal_002dtime_002fticks_002d_003eseconds-2711")
	("interpreter-environment?" "Top_002dlevel-Environments.html#index-interpreter_002denvironment_003f-1944")
	("invoke-restart" "Establishing-Restart-Code.html#index-invoke_002drestart-2856")
	("invoke-restart" "Finding-and-Invoking-General-Restart-Code.html#index-invoke_002drestart-2877")
	("invoke-restart" "Restarts.html#index-invoke_002drestart-2843")
	("invoke-restart" "The-Named-Restart-Abstraction.html#index-invoke_002drestart-2885")
	("invoke-restart-interactively" "The-Named-Restart-Abstraction.html#index-invoke_002drestart_002dinteractively-2888")
	("invoke-restart-interactively" "Restarts.html#index-invoke_002drestart_002dinteractively-2844")
	("invoke-restart-interactively" "Finding-and-Invoking-General-Restart-Code.html#index-invoke_002drestart_002dinteractively-2874")
	("invoke-restart-interactively" "The-Named-Restart-Abstraction.html#index-invoke_002drestart_002dinteractively-2886")
	("iota" "Construction-of-Lists.html#index-iota-1171")
	("keep-matching-items" "Filtering-Lists.html#index-keep_002dmatching_002ditems-1223")
	("keep-matching-items!" "Filtering-Lists.html#index-keep_002dmatching_002ditems_0021-1232")
	("kernel32.dll" "Windows-Foreign-Procedures.html#index-kernel32_002edll-3158")
	("keyword-constructor" "Structure-Definitions.html#index-keyword_002dconstructor-356")
	("lambda" "Internal-Definitions.html#index-lambda-260")
	("lambda" "Definitions.html#index-lambda-242")
	("lambda" "Lexical-Binding.html#index-lambda-221")
	("lambda" "Lambda-Expressions.html#index-lambda-178")
	("lambda" "Procedure-Call-Syntax.html#index-lambda-175")
	("lambda" "Additional-Notations.html#index-lambda-150")
	("lambda" "Static-Scoping.html#index-lambda-99")
	("lambda" "Procedures.html#index-lambda-1799")
	("lambda" "Entry-Format.html#index-lambda-51")
	("lambda" "Sequencing.html#index-lambda-329")
	("last-pair" "Cutting-and-Pasting-Lists.html#index-last_002dpair-1217")
	("lcm" "Numerical-operations.html#index-lcm-552")
	("length" "Implementation-restrictions.html#index-length-440")
	("length" "Selecting-List-Components.html#index-length-1189")
	("length+" "Selecting-List-Components.html#index-length_002b-1190")
	("let" "Lexical-Binding.html#index-let-211")
	("let" "Dynamic-Binding.html#index-let-228")
	("let" "Internal-Definitions.html#index-let-261")
	("let" "Definitions.html#index-let-243")
	("let" "Sequencing.html#index-let-330")
	("let" "Environment-Concepts.html#index-let-77")
	("let" "Iteration.html#index-let-339")
	("let*" "Definitions.html#index-let_002a-244")
	("let*" "Sequencing.html#index-let_002a-331")
	("let*" "Internal-Definitions.html#index-let_002a-262")
	("let*" "Lexical-Binding.html#index-let_002a-215")
	("let*" "Environment-Concepts.html#index-let_002a-78")
	("let*-syntax" "Syntactic-Binding-Constructs.html#index-let_002a_002dsyntax-375")
	("let-syntax" "Syntactic-Binding-Constructs.html#index-let_002dsyntax-373")
	("letrec" "Definitions.html#index-letrec-245")
	("letrec" "Sequencing.html#index-letrec-332")
	("letrec" "Lexical-Binding.html#index-letrec-218")
	("letrec" "Internal-Definitions.html#index-letrec-266")
	("letrec" "Environment-Concepts.html#index-letrec-79")
	("letrec" "Internal-Definitions.html#index-letrec-263")
	("letrec-syntax" "Syntactic-Binding-Constructs.html#index-letrec_002dsyntax-374")
	("link-variables" "Top_002dlevel-Environments.html#index-link_002dvariables-1949")
	("list" "Construction-of-Vectors.html#index-list-1318")
	("list" "Entry-Format.html#index-list-55")
	("list" "Miscellaneous-List-Operations.html#index-list-1291")
	("list" "Construction-of-Lists.html#index-list-1164")
	("list->stream" "Streams.html#index-list_002d_003estream-1531")
	("list->string" "Construction-of-Strings.html#index-list_002d_003estring-896")
	("list->string" "Construction-of-Lists.html#index-list_002d_003estring-1179")
	("list->vector" "Construction-of-Lists.html#index-list_002d_003evector-1175")
	("list->vector" "Construction-of-Vectors.html#index-list_002d_003evector-1321")
	("list-copy" "Association-Lists.html#index-list_002dcopy-1619")
	("list-copy" "Construction-of-Lists.html#index-list_002dcopy-1170")
	("list-deletor" "Association-Lists.html#index-list_002ddeletor-1615")
	("list-deletor" "Filtering-Lists.html#index-list_002ddeletor-1247")
	("list-deletor!" "Filtering-Lists.html#index-list_002ddeletor_0021-1248")
	("list-deletor!" "Association-Lists.html#index-list_002ddeletor_0021-1616")
	("list-deletor!" "Filtering-Lists.html#index-list_002ddeletor_0021-1252")
	("list-head" "Cutting-and-Pasting-Lists.html#index-list_002dhead-1212")
	("list-ref" "Selecting-List-Components.html#index-list_002dref-1194")
	("list-search-negative" "Searching-Lists.html#index-list_002dsearch_002dnegative-1257")
	("list-search-positive" "Searching-Lists.html#index-list_002dsearch_002dpositive-1256")
	("list-tabulate" "Construction-of-Lists.html#index-list_002dtabulate-1168")
	("list-tail" "Selecting-List-Components.html#index-list_002dtail-1198")
	("list-tail" "Cutting-and-Pasting-Lists.html#index-list_002dtail-1213")
	("list-transform-negative" "Filtering-Lists.html#index-list_002dtransform_002dnegative-1227")
	("list-transform-positive" "Filtering-Lists.html#index-list_002dtransform_002dpositive-1224")
	("list?" "Association-Lists.html#index-list_003f-1592")
	("list?" "Selecting-List-Components.html#index-list_003f-1182")
	("list?" "1D-Tables.html#index-list_003f-1628")
	("load-bitmap on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-load_002dbitmap-on-win32_002dgraphics_002ddevice-3107")
	("load-option" "Weight_002dBalanced-Trees.html#index-load_002doption-1761")
	("load-option" "XML-Support.html#index-load_002doption-2319")
	("load-option" "Red_002dBlack-Trees.html#index-load_002doption-1724")
	("load-option" "Parser-Language.html#index-load_002doption-2270")
	("load-option" "Format.html#index-load_002doption-2121")
	("local-decoded-time" "Decoded-Time.html#index-local_002ddecoded_002dtime-2671")
	("local-host" "Miscellaneous-Pathnames.html#index-local_002dhost-2552")
	("log" "Numerical-operations.html#index-log-572")
	("long" "Windows-Types.html#index-long-3132")
	("magnitude" "Numerical-operations.html#index-magnitude-588")
	("make-1d-table" "1D-Tables.html#index-make_002d1d_002dtable-1625")
	("make-apply-hook" "Application-Hooks.html#index-make_002dapply_002dhook-1862")
	("make-bit-string" "Construction-of-Bit-Strings.html#index-make_002dbit_002dstring-1371")
	("make-cell" "Cells.html#index-make_002dcell-1490")
	("make-char" "Internal-Representation-of-Characters.html#index-make_002dchar-741")
	("make-circular-list" "Miscellaneous-List-Operations.html#index-make_002dcircular_002dlist-1288")
	("make-condition" "Simple-Condition-Instance-Operations.html#index-make_002dcondition-2915")
	("make-condition" "Condition-Signalling.html#index-make_002dcondition-2781")
	("make-condition-type" "Condition-Types.html#index-make_002dcondition_002dtype-2925")
	("make-decoded-time" "Decoded-Time.html#index-make_002ddecoded_002dtime-2673")
	("make-directory" "File-Manipulation.html#index-make_002ddirectory-2600")
	("make-entity" "Application-Hooks.html#index-make_002dentity-1869")
	("make-eof-object" "Constructors-and-Accessors-for-Ports.html#index-make_002deof_002dobject-2169")
	("make-ephemeron" "Ephemerons.html#index-make_002dephemeron-1576")
	("make-eq-hash-table" "Construction-of-Hash-Tables.html#index-make_002deq_002dhash_002dtable-1652")
	("make-equal-hash-table" "Construction-of-Hash-Tables.html#index-make_002dequal_002dhash_002dtable-1660")
	("make-eqv-hash-table" "Construction-of-Hash-Tables.html#index-make_002deqv_002dhash_002dtable-1658")
	("make-generic-procedure" "Generic-Procedures.html#index-make_002dgeneric_002dprocedure-1879")
	("make-graphics-device" "Opening-and-Closing-of-Graphics-Devices.html#index-make_002dgraphics_002ddevice-2980")
	("make-initialized-list" "Construction-of-Lists.html#index-make_002dinitialized_002dlist-1169")
	("make-initialized-vector" "Construction-of-Vectors.html#index-make_002dinitialized_002dvector-1324")
	("make-list" "Miscellaneous-List-Operations.html#index-make_002dlist-1292")
	("make-list" "Construction-of-Lists.html#index-make_002dlist-1165")
	("make-parser-macros" "Parser_002dlanguage-Macros.html#index-make_002dparser_002dmacros-2311")
	("make-pathname" "Components-of-Pathnames.html#index-make_002dpathname-2507")
	("make-polar" "Numerical-operations.html#index-make_002dpolar-585")
	("make-port" "Constructors-and-Accessors-for-Ports.html#index-make_002dport-2163")
	("make-port-type" "Port-Types.html#index-make_002dport_002dtype-2154")
	("make-primitive-procedure" "Primitive-Procedures.html#index-make_002dprimitive_002dprocedure-1837")
	("make-procedure-arity" "Arity.html#index-make_002dprocedure_002darity-1825")
	("make-random-state" "Random-Numbers.html#index-make_002drandom_002dstate-680")
	("make-rb-tree" "Red_002dBlack-Trees.html#index-make_002drb_002dtree-1725")
	("make-record-type" "Records.html#index-make_002drecord_002dtype-1498")
	("make-rectangular" "Numerical-operations.html#index-make_002drectangular-584")
	("make-root-top-level-environment" "Top_002dlevel-Environments.html#index-make_002droot_002dtop_002dlevel_002denvironment-1948")
	("make-string" "Construction-of-Strings.html#index-make_002dstring-894")
	("make-string-hash-table" "Construction-of-Hash-Tables.html#index-make_002dstring_002dhash_002dtable-1662")
	("make-strong-eq-hash-table" "Construction-of-Hash-Tables.html#index-make_002dstrong_002deq_002dhash_002dtable-1648")
	("make-strong-eqv-hash-table" "Construction-of-Hash-Tables.html#index-make_002dstrong_002deqv_002dhash_002dtable-1654")
	("make-syntactic-closure" "SC-Transformer-Definition.html#index-make_002dsyntactic_002dclosure-393")
	("make-synthetic-identifier" "SC-Identifiers.html#index-make_002dsynthetic_002didentifier-399")
	("make-top-level-environment" "Top_002dlevel-Environments.html#index-make_002dtop_002dlevel_002denvironment-1947")
	("make-vector" "Construction-of-Vectors.html#index-make_002dvector-1316")
	("make-weak-eq-hash-table" "Construction-of-Hash-Tables.html#index-make_002dweak_002deq_002dhash_002dtable-1650")
	("make-weak-eqv-hash-table" "Construction-of-Hash-Tables.html#index-make_002dweak_002deqv_002dhash_002dtable-1656")
	("make-wide-string" "Wide-Strings.html#index-make_002dwide_002dstring-827")
	("make-wt-tree" "Construction-of-Weight_002dBalanced-Trees.html#index-make_002dwt_002dtree-1765")
	("make-wt-tree-type" "Construction-of-Weight_002dBalanced-Trees.html#index-make_002dwt_002dtree_002dtype-1762")
	("make-xml-!attlist" "XML-Structure.html#index-make_002dxml_002d_0021attlist-2429")
	("make-xml-!element" "XML-Structure.html#index-make_002dxml_002d_0021element-2421")
	("make-xml-!entity" "XML-Structure.html#index-make_002dxml_002d_0021entity-2437")
	("make-xml-!notation" "XML-Structure.html#index-make_002dxml_002d_0021notation-2463")
	("make-xml-declaration" "XML-Structure.html#index-make_002dxml_002ddeclaration-2383")
	("make-xml-document" "XML-Structure.html#index-make_002dxml_002ddocument-2367")
	("make-xml-dtd" "XML-Structure.html#index-make_002dxml_002ddtd-2411")
	("make-xml-element" "XML-Structure.html#index-make_002dxml_002delement-2393")
	("make-xml-external-id" "XML-Structure.html#index-make_002dxml_002dexternal_002did-2471")
	("make-xml-name" "XML-Names.html#index-make_002dxml_002dname-2338")
	("make-xml-nmtoken" "XML-Names.html#index-make_002dxml_002dnmtoken-2360")
	("make-xml-parameter-!entity" "XML-Structure.html#index-make_002dxml_002dparameter_002d_0021entity-2445")
	("make-xml-processing-instructions" "XML-Structure.html#index-make_002dxml_002dprocessing_002dinstructions-2403")
	("make-xml-qname" "XML-Names.html#index-make_002dxml_002dqname-2350")
	("make-xml-unparsed-!entity" "XML-Structure.html#index-make_002dxml_002dunparsed_002d_0021entity-2453")
	("map" "_002aParser.html#index-map-2304")
	("map" "Mapping-of-Lists.html#index-map-1267")
	("map*" "Mapping-of-Lists.html#index-map_002a-1268")
	("map-window on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-map_002dwindow-on-x_002dgraphics_002ddevice-3070")
	("match" "_002aParser.html#index-match-2293")
	("match-parser-buffer-char" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dchar-2245")
	("match-parser-buffer-char-ci" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dchar_002dci-2246")
	("match-parser-buffer-char-ci-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dchar_002dci_002dno_002dadvance-2250")
	("match-parser-buffer-char-in-set" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dchar_002din_002dset-2253")
	("match-parser-buffer-char-in-set-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dchar_002din_002dset_002dno_002dadvance-2254")
	("match-parser-buffer-char-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dchar_002dno_002dadvance-2249")
	("match-parser-buffer-not-char" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dnot_002dchar-2247")
	("match-parser-buffer-not-char-ci" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dnot_002dchar_002dci-2248")
	("match-parser-buffer-not-char-ci-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dnot_002dchar_002dci_002dno_002dadvance-2252")
	("match-parser-buffer-not-char-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dnot_002dchar_002dno_002dadvance-2251")
	("match-parser-buffer-string" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dstring-2255")
	("match-parser-buffer-string-ci" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dstring_002dci-2256")
	("match-parser-buffer-string-ci-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dstring_002dci_002dno_002dadvance-2258")
	("match-parser-buffer-string-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dstring_002dno_002dadvance-2257")
	("match-parser-buffer-substring" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dsubstring-2259")
	("match-parser-buffer-substring-ci" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dsubstring_002dci-2260")
	("match-parser-buffer-substring-ci-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dsubstring_002dci_002dno_002dadvance-2262")
	("match-parser-buffer-substring-no-advance" "Parser-Buffers.html#index-match_002dparser_002dbuffer_002dsubstring_002dno_002dadvance-2261")
	("max" "Numerical-operations.html#index-max-506")
	("measure-interval" "Machine-Time.html#index-measure_002dinterval-2716")
	("member" "Searching-Lists.html#index-member-1261")
	("member-procedure" "Searching-Lists.html#index-member_002dprocedure-1265")
	("memq" "Searching-Lists.html#index-memq-1259")
	("memv" "Searching-Lists.html#index-memv-1260")
	("merge-pathnames" "Operations-on-Pathnames.html#index-merge_002dpathnames-2532")
	("merge-pathnames" "File-Ports.html#index-merge_002dpathnames-2007")
	("merge-sort" "Miscellaneous-List-Operations.html#index-merge_002dsort-1297")
	("merge-sort!" "Modifying-Vectors.html#index-merge_002dsort_0021-1358")
	("microcode-id/operating-system" "Miscellaneous-OS-Facilities.html#index-microcode_002did_002foperating_002dsystem-2747")
	("microcode-id/operating-system-name" "Miscellaneous-OS-Facilities.html#index-microcode_002did_002foperating_002dsystem_002dname-2748")
	("microcode-id/operating-system-variant" "Miscellaneous-OS-Facilities.html#index-microcode_002did_002foperating_002dsystem_002dvariant-2749")
	("min" "Numerical-operations.html#index-min-507")
	("modulo" "Numerical-operations.html#index-modulo-534")
	("month/long-string" "External-Representation-of-Time.html#index-month_002flong_002dstring-2705")
	("month/max-days" "Decoded-Time.html#index-month_002fmax_002ddays-2684")
	("month/short-string" "External-Representation-of-Time.html#index-month_002fshort_002dstring-2706")
	("move-window on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-move_002dwindow-on-win32_002dgraphics_002ddevice-3111")
	("move-window on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-move_002dwindow-on-x_002dgraphics_002ddevice-3073")
	("muffle-warning" "Restarts.html#index-muffle_002dwarning-2847")
	("muffle-warning" "Condition-Signalling.html#index-muffle_002dwarning-2787")
	("muffle-warning" "Condition-Handling.html#index-muffle_002dwarning-2832")
	("muffle-warning" "Invoking-Standard-Restart-Code.html#index-muffle_002dwarning-2861")
	("name->char" "External-Representation-of-Characters.html#index-name_002d_003echar-710")
	("named" "Structure-Definitions.html#index-named-361")
	("named-lambda" "Sequencing.html#index-named_002dlambda-333")
	("named-lambda" "Lambda-Expressions.html#index-named_002dlambda-206")
	("named-lambda" "Definitions.html#index-named_002dlambda-250")
	("NaN" "Flonum-Operations.html#index-NaN-648")
	("nearest-repl/environment" "REPL-Environment.html#index-nearest_002drepl_002fenvironment-1933")
	("negative?" "Numerical-operations.html#index-negative_003f-498")
	("newline" "Output-Procedures.html#index-newline-2097")
	("nil" "Booleans.html#index-nil-1432")
	("ninth" "Selecting-List-Components.html#index-ninth-1207")
	("noise" "_002aParser.html#index-noise-2294")
	("not" "Booleans.html#index-not-1437")
	("not-char" "_002aMatcher.html#index-not_002dchar-2276")
	("not-char-ci" "_002aMatcher.html#index-not_002dchar_002dci-2277")
	("notification-output-port" "Condition-Handling.html#index-notification_002doutput_002dport-2830")
	("notification-output-port" "Ports.html#index-notification_002doutput_002dport-1980")
	("nt-file-mode/archive" "File-Manipulation.html#index-nt_002dfile_002dmode_002farchive-2629")
	("nt-file-mode/compressed" "File-Manipulation.html#index-nt_002dfile_002dmode_002fcompressed-2632")
	("nt-file-mode/directory" "File-Manipulation.html#index-nt_002dfile_002dmode_002fdirectory-2628")
	("nt-file-mode/hidden" "File-Manipulation.html#index-nt_002dfile_002dmode_002fhidden-2626")
	("nt-file-mode/normal" "File-Manipulation.html#index-nt_002dfile_002dmode_002fnormal-2630")
	("nt-file-mode/read-only" "File-Manipulation.html#index-nt_002dfile_002dmode_002fread_002donly-2625")
	("nt-file-mode/system" "File-Manipulation.html#index-nt_002dfile_002dmode_002fsystem-2627")
	("nt-file-mode/temporary" "File-Manipulation.html#index-nt_002dfile_002dmode_002ftemporary-2631")
	("null-xml-name-prefix" "XML-Names.html#index-null_002dxml_002dname_002dprefix-2354")
	("null-xml-name-prefix?" "XML-Names.html#index-null_002dxml_002dname_002dprefix_003f-2355")
	("null-xml-namespace-uri" "XML-Names.html#index-null_002dxml_002dnamespace_002duri-2356")
	("null-xml-namespace-uri?" "XML-Names.html#index-null_002dxml_002dnamespace_002duri_003f-2357")
	("null?" "Selecting-List-Components.html#index-null_003f-1191")
	("null?" "Streams.html#index-null_003f-1547")
	("number->string" "Numerical-input-and-output.html#index-number_002d_003estring-595")
	("number-wt-type" "Construction-of-Weight_002dBalanced-Trees.html#index-number_002dwt_002dtype-1763")
	("number?" "Numerical-operations.html#index-number_003f-475")
	("numerator" "Numerical-operations.html#index-numerator-555")
	("object-hash" "Object-Hashing.html#index-object_002dhash-1714")
	("object-hashed?" "Object-Hashing.html#index-object_002dhashed_003f-1712")
	("object-unhash" "Object-Hashing.html#index-object_002dunhash-1716")
	("odd?" "Numerical-operations.html#index-odd_003f-499")
	("open-binary-i/o-file" "File-Ports.html#index-open_002dbinary_002di_002fo_002dfile-2022")
	("open-binary-input-file" "File-Ports.html#index-open_002dbinary_002dinput_002dfile-2020")
	("open-binary-output-file" "File-Ports.html#index-open_002dbinary_002doutput_002dfile-2021")
	("open-dib" "DIB-procedures.html#index-open_002ddib-3168")
	("open-i/o-file" "File-Ports.html#index-open_002di_002fo_002dfile-2017")
	("open-input-file" "File-Ports.html#index-open_002dinput_002dfile-2010")
	("open-input-string" "String-Ports.html#index-open_002dinput_002dstring-2042")
	("open-output-file" "File-Ports.html#index-open_002doutput_002dfile-2013")
	("open-output-string" "String-Ports.html#index-open_002doutput_002dstring-2047")
	("open-tcp-server-socket" "TCP-Sockets.html#index-open_002dtcp_002dserver_002dsocket-2744")
	("open-tcp-stream-socket" "TCP-Sockets.html#index-open_002dtcp_002dstream_002dsocket-2742")
	("open-wide-input-string" "Wide-Strings.html#index-open_002dwide_002dinput_002dstring-834")
	("open-wide-output-string" "Wide-Strings.html#index-open_002dwide_002doutput_002dstring-835")
	("or" "Conditionals.html#index-or-320")
	("or" "Booleans.html#index-or-1430")
	("os/hostname" "Miscellaneous-OS-Facilities.html#index-os_002fhostname-2754")
	("output" "Subprocess-Options.html#index-output-2727")
	("output-buffer-size" "Subprocess-Options.html#index-output_002dbuffer_002dsize-2729")
	("output-buffer-size on output port" "Output-Port-Operations.html#index-output_002dbuffer_002dsize-on-output-port-2208")
	("output-line-translation" "Subprocess-Options.html#index-output_002dline_002dtranslation-2728")
	("output-port-type?" "Port-Types.html#index-output_002dport_002dtype_003f-2158")
	("output-port/discretionary-flush-output" "Output-Port-Operations.html#index-output_002dport_002fdiscretionary_002dflush_002doutput-2205")
	("output-port/flush-output" "Output-Port-Operations.html#index-output_002dport_002fflush_002doutput-2204")
	("output-port/fresh-line" "Output-Port-Operations.html#index-output_002dport_002ffresh_002dline-2203")
	("output-port/write-char" "Output-Port-Operations.html#index-output_002dport_002fwrite_002dchar-2201")
	("output-port/write-string" "Output-Port-Operations.html#index-output_002dport_002fwrite_002dstring-2206")
	("output-port/write-substring" "Output-Port-Operations.html#index-output_002dport_002fwrite_002dsubstring-2202")
	("output-port/x-size" "Output-Port-Operations.html#index-output_002dport_002fx_002dsize-2212")
	("output-port/y-size" "Output-Port-Operations.html#index-output_002dport_002fy_002dsize-2213")
	("output-port?" "Ports.html#index-output_002dport_003f-1968")
	("pair?" "Pairs.html#index-pair_003f-1118")
	("pair?" "Selecting-List-Components.html#index-pair_003f-1185")
	("pair?" "Weak-Pairs.html#index-pair_003f-1559")
	("parse-namestring" "Filenames-and-Pathnames.html#index-parse_002dnamestring-2485")
	("parser-buffer-pointer-index" "Parser-Buffers.html#index-parser_002dbuffer_002dpointer_002dindex-2264")
	("parser-buffer-pointer-line" "Parser-Buffers.html#index-parser_002dbuffer_002dpointer_002dline-2265")
	("parser-buffer-pointer?" "Parser-Buffers.html#index-parser_002dbuffer_002dpointer_003f-2237")
	("parser-buffer-position-string" "Parser-Buffers.html#index-parser_002dbuffer_002dposition_002dstring-2263")
	("parser-buffer-ref" "Parser-Buffers.html#index-parser_002dbuffer_002dref-2240")
	("parser-buffer?" "Parser-Buffers.html#index-parser_002dbuffer_003f-2236")
	("parser-macros?" "Parser_002dlanguage-Macros.html#index-parser_002dmacros_003f-2312")
	("partition" "Filtering-Lists.html#index-partition-1228")
	("partition!" "Filtering-Lists.html#index-partition_0021-1231")
	("pathname-absolute?" "Operations-on-Pathnames.html#index-pathname_002dabsolute_003f-2529")
	("pathname-as-directory" "Operations-on-Pathnames.html#index-pathname_002das_002ddirectory-2549")
	("pathname-as-directory" "Working-Directory.html#index-pathname_002das_002ddirectory-2578")
	("pathname-default" "Operations-on-Pathnames.html#index-pathname_002ddefault-2537")
	("pathname-default-device" "Components-of-Pathnames.html#index-pathname_002ddefault_002ddevice-2520")
	("pathname-default-directory" "Components-of-Pathnames.html#index-pathname_002ddefault_002ddirectory-2521")
	("pathname-default-name" "Components-of-Pathnames.html#index-pathname_002ddefault_002dname-2522")
	("pathname-default-type" "Components-of-Pathnames.html#index-pathname_002ddefault_002dtype-2523")
	("pathname-default-version" "Components-of-Pathnames.html#index-pathname_002ddefault_002dversion-2524")
	("pathname-device" "Components-of-Pathnames.html#index-pathname_002ddevice-2510")
	("pathname-directory" "Components-of-Pathnames.html#index-pathname_002ddirectory-2511")
	("pathname-host" "Components-of-Pathnames.html#index-pathname_002dhost-2509")
	("pathname-name" "Components-of-Pathnames.html#index-pathname_002dname-2512")
	("pathname-new-device" "Components-of-Pathnames.html#index-pathname_002dnew_002ddevice-2515")
	("pathname-new-directory" "Components-of-Pathnames.html#index-pathname_002dnew_002ddirectory-2516")
	("pathname-new-name" "Components-of-Pathnames.html#index-pathname_002dnew_002dname-2517")
	("pathname-new-type" "Components-of-Pathnames.html#index-pathname_002dnew_002dtype-2518")
	("pathname-new-version" "Components-of-Pathnames.html#index-pathname_002dnew_002dversion-2519")
	("pathname-simplify" "Filenames-and-Pathnames.html#index-pathname_002dsimplify-2489")
	("pathname-type" "Components-of-Pathnames.html#index-pathname_002dtype-2513")
	("pathname-version" "Components-of-Pathnames.html#index-pathname_002dversion-2514")
	("pathname-wild?" "Operations-on-Pathnames.html#index-pathname_002dwild_003f-2531")
	("pathname=?" "Operations-on-Pathnames.html#index-pathname_003d_003f-2527")
	("pathname?" "Operations-on-Pathnames.html#index-pathname_003f-2525")
	("peek-char" "Input-Procedures.html#index-peek_002dchar-2060")
	("peek-char on input port" "Input-Port-Operations.html#index-peek_002dchar-on-input-port-2176")
	("peek-parser-buffer-char" "Parser-Buffers.html#index-peek_002dparser_002dbuffer_002dchar-2239")
	("port-type/operation" "Port-Types.html#index-port_002dtype_002foperation-2162")
	("port-type/operation-names" "Port-Types.html#index-port_002dtype_002foperation_002dnames-2161")
	("port-type/operations" "Port-Types.html#index-port_002dtype_002foperations-2160")
	("port-type?" "Port-Types.html#index-port_002dtype_003f-2156")
	("port/input-blocking-mode" "Blocking-Mode.html#index-port_002finput_002dblocking_002dmode-2215")
	("port/input-terminal-mode" "Terminal-Mode.html#index-port_002finput_002dterminal_002dmode-2224")
	("port/operation" "Constructors-and-Accessors-for-Ports.html#index-port_002foperation-2167")
	("port/operation-names" "Constructors-and-Accessors-for-Ports.html#index-port_002foperation_002dnames-2168")
	("port/output-blocking-mode" "Blocking-Mode.html#index-port_002foutput_002dblocking_002dmode-2218")
	("port/output-terminal-mode" "Terminal-Mode.html#index-port_002foutput_002dterminal_002dmode-2227")
	("port/set-input-blocking-mode" "Blocking-Mode.html#index-port_002fset_002dinput_002dblocking_002dmode-2216")
	("port/set-input-terminal-mode" "Terminal-Mode.html#index-port_002fset_002dinput_002dterminal_002dmode-2225")
	("port/set-output-blocking-mode" "Blocking-Mode.html#index-port_002fset_002doutput_002dblocking_002dmode-2219")
	("port/set-output-terminal-mode" "Terminal-Mode.html#index-port_002fset_002doutput_002dterminal_002dmode-2228")
	("port/state" "Constructors-and-Accessors-for-Ports.html#index-port_002fstate-2165")
	("port/type" "Constructors-and-Accessors-for-Ports.html#index-port_002ftype-2164")
	("port/with-input-blocking-mode" "Blocking-Mode.html#index-port_002fwith_002dinput_002dblocking_002dmode-2217")
	("port/with-input-terminal-mode" "Terminal-Mode.html#index-port_002fwith_002dinput_002dterminal_002dmode-2226")
	("port/with-output-blocking-mode" "Blocking-Mode.html#index-port_002fwith_002doutput_002dblocking_002dmode-2220")
	("port/with-output-terminal-mode" "Terminal-Mode.html#index-port_002fwith_002doutput_002dterminal_002dmode-2229")
	("port?" "Ports.html#index-port_003f-1965")
	("positive?" "Numerical-operations.html#index-positive_003f-497")
	("pp" "Output-Procedures.html#index-pp-2112")
	("predicate" "Structure-Definitions.html#index-predicate-350")
	("primitive-procedure-name" "Primitive-Procedures.html#index-primitive_002dprocedure_002dname-1838")
	("primitive-procedure?" "Procedure-Operations.html#index-primitive_002dprocedure_003f-1821")
	("print-procedure" "Structure-Definitions.html#index-print_002dprocedure-352")
	("procedure-arity" "Arity.html#index-procedure_002darity-1831")
	("procedure-arity-max" "Arity.html#index-procedure_002darity_002dmax-1829")
	("procedure-arity-min" "Arity.html#index-procedure_002darity_002dmin-1828")
	("procedure-arity-valid?" "Arity.html#index-procedure_002darity_002dvalid_003f-1832")
	("procedure-arity?" "Arity.html#index-procedure_002darity_003f-1826")
	("procedure-environment" "Procedure-Operations.html#index-procedure_002denvironment-1823")
	("procedure-of-arity?" "Arity.html#index-procedure_002dof_002darity_003f-1833")
	("procedure?" "Procedure-Operations.html#index-procedure_003f-1815")
	("process-time-clock" "Machine-Time.html#index-process_002dtime_002dclock-2709")
	("promise-forced?" "Promises.html#index-promise_002dforced_003f-1526")
	("promise-value" "Promises.html#index-promise_002dvalue-1527")
	("promise?" "Promises.html#index-promise_003f-1524")
	("prompt-for-command-char" "Prompting.html#index-prompt_002dfor_002dcommand_002dchar-2142")
	("prompt-for-command-expression" "Prompting.html#index-prompt_002dfor_002dcommand_002dexpression-2141")
	("prompt-for-confirmation" "Prompting.html#index-prompt_002dfor_002dconfirmation-2148")
	("prompt-for-evaluated-expression" "Prompting.html#index-prompt_002dfor_002devaluated_002dexpression-2147")
	("prompt-for-expression" "Prompting.html#index-prompt_002dfor_002dexpression-2146")
	("pwd" "Working-Directory.html#index-pwd-2574")
	("quasiquote" "Lists.html#index-quasiquote-1110")
	("quasiquote" "Quoting.html#index-quasiquote-283")
	("quick-sort" "Miscellaneous-List-Operations.html#index-quick_002dsort-1298")
	("quick-sort!" "Modifying-Vectors.html#index-quick_002dsort_0021-1359")
	("quote" "Lists.html#index-quote-1109")
	("quote" "Quoting.html#index-quote-275")
	("quotient" "Numerical-operations.html#index-quotient-532")
	("random" "Random-Numbers.html#index-random-677")
	("random-state?" "Random-Numbers.html#index-random_002dstate_003f-681")
	("rational?" "Numerical-operations.html#index-rational_003f-478")
	("rationalize" "Numerical-operations.html#index-rationalize-565")
	("rationalize->exact" "Numerical-operations.html#index-rationalize_002d_003eexact-566")
	("rb-tree->alist" "Red_002dBlack-Trees.html#index-rb_002dtree_002d_003ealist-1730")
	("rb-tree/copy" "Red_002dBlack-Trees.html#index-rb_002dtree_002fcopy-1737")
	("rb-tree/datum-list" "Red_002dBlack-Trees.html#index-rb_002dtree_002fdatum_002dlist-1732")
	("rb-tree/delete!" "Red_002dBlack-Trees.html#index-rb_002dtree_002fdelete_0021-1729")
	("rb-tree/delete-max!" "Red_002dBlack-Trees.html#index-rb_002dtree_002fdelete_002dmax_0021-1748")
	("rb-tree/delete-max-datum!" "Red_002dBlack-Trees.html#index-rb_002dtree_002fdelete_002dmax_002ddatum_0021-1749")
	("rb-tree/delete-max-pair!" "Red_002dBlack-Trees.html#index-rb_002dtree_002fdelete_002dmax_002dpair_0021-1750")
	("rb-tree/delete-min!" "Red_002dBlack-Trees.html#index-rb_002dtree_002fdelete_002dmin_0021-1745")
	("rb-tree/delete-min-datum!" "Red_002dBlack-Trees.html#index-rb_002dtree_002fdelete_002dmin_002ddatum_0021-1746")
	("rb-tree/delete-min-pair!" "Red_002dBlack-Trees.html#index-rb_002dtree_002fdelete_002dmin_002dpair_0021-1747")
	("rb-tree/empty?" "Red_002dBlack-Trees.html#index-rb_002dtree_002fempty_003f-1734")
	("rb-tree/equal?" "Red_002dBlack-Trees.html#index-rb_002dtree_002fequal_003f-1733")
	("rb-tree/height" "Red_002dBlack-Trees.html#index-rb_002dtree_002fheight-1736")
	("rb-tree/insert!" "Red_002dBlack-Trees.html#index-rb_002dtree_002finsert_0021-1727")
	("rb-tree/key-list" "Red_002dBlack-Trees.html#index-rb_002dtree_002fkey_002dlist-1731")
	("rb-tree/lookup" "Red_002dBlack-Trees.html#index-rb_002dtree_002flookup-1728")
	("rb-tree/max" "Red_002dBlack-Trees.html#index-rb_002dtree_002fmax-1742")
	("rb-tree/max-datum" "Red_002dBlack-Trees.html#index-rb_002dtree_002fmax_002ddatum-1743")
	("rb-tree/max-pair" "Red_002dBlack-Trees.html#index-rb_002dtree_002fmax_002dpair-1744")
	("rb-tree/min" "Red_002dBlack-Trees.html#index-rb_002dtree_002fmin-1739")
	("rb-tree/min-datum" "Red_002dBlack-Trees.html#index-rb_002dtree_002fmin_002ddatum-1740")
	("rb-tree/min-pair" "Red_002dBlack-Trees.html#index-rb_002dtree_002fmin_002dpair-1741")
	("rb-tree/size" "Red_002dBlack-Trees.html#index-rb_002dtree_002fsize-1735")
	("rb-tree?" "Red_002dBlack-Trees.html#index-rb_002dtree_003f-1726")
	("re-match-end-index" "Regular_002dexpression-procedures.html#index-re_002dmatch_002dend_002dindex-1021")
	("re-match-extract" "Regular_002dexpression-procedures.html#index-re_002dmatch_002dextract-1022")
	("re-match-start-index" "Regular_002dexpression-procedures.html#index-re_002dmatch_002dstart_002dindex-1020")
	("re-string-match" "Regular_002dexpression-procedures.html#index-re_002dstring_002dmatch-1014")
	("re-string-search-backward" "Regular_002dexpression-procedures.html#index-re_002dstring_002dsearch_002dbackward-1018")
	("re-string-search-forward" "Regular_002dexpression-procedures.html#index-re_002dstring_002dsearch_002dforward-1016")
	("re-substring-match" "Regular_002dexpression-procedures.html#index-re_002dsubstring_002dmatch-1015")
	("re-substring-search-backward" "Regular_002dexpression-procedures.html#index-re_002dsubstring_002dsearch_002dbackward-1019")
	("re-substring-search-forward" "Regular_002dexpression-procedures.html#index-re_002dsubstring_002dsearch_002dforward-1017")
	("read" "Overview.html#index-read-19")
	("read" "Input-Procedures.html#index-read-2063")
	("read" "Ports.html#index-read-1960")
	("read" "Symbols.html#index-read-1452")
	("read" "Lists.html#index-read-1117")
	("read" "External-Representation-of-Characters.html#index-read-709")
	("read" "External-Representations.html#index-read-107")
	("read-char" "Input-Procedures.html#index-read_002dchar-2075")
	("read-char" "Ports.html#index-read_002dchar-1959")
	("read-char" "Input-Procedures.html#index-read_002dchar-2058")
	("read-char on input port" "Input-Port-Operations.html#index-read_002dchar-on-input-port-2174")
	("read-char-no-hang" "Input-Procedures.html#index-read_002dchar_002dno_002dhang-2072")
	("read-line" "Input-Procedures.html#index-read_002dline-2076")
	("read-only" "Structure-Definitions.html#index-read_002donly-348")
	("read-parser-buffer-char" "Parser-Buffers.html#index-read_002dparser_002dbuffer_002dchar-2238")
	("read-string" "Input-Procedures.html#index-read_002dstring-2073")
	("read-string on input port" "Input-Port-Operations.html#index-read_002dstring-on-input-port-2178")
	("read-string!" "Input-Procedures.html#index-read_002dstring_0021-2077")
	("read-substring on input port" "Input-Port-Operations.html#index-read_002dsubstring-on-input-port-2181")
	("read-substring!" "Input-Procedures.html#index-read_002dsubstring_0021-2078")
	("read-xml" "XML-Input.html#index-read_002dxml-2324")
	("read-xml-file" "XML-Input.html#index-read_002dxml_002dfile-2325")
	("real-part" "Numerical-operations.html#index-real_002dpart-586")
	("real-time-clock" "Machine-Time.html#index-real_002dtime_002dclock-2710")
	("real?" "Numerical-operations.html#index-real_003f-477")
	("receive" "receive-_0028SRFI-8_0029.html#index-receive-410")
	("record-accessor" "Records.html#index-record_002daccessor-1503")
	("record-constructor" "Records.html#index-record_002dconstructor-1500")
	("record-keyword-constructor" "Records.html#index-record_002dkeyword_002dconstructor-1501")
	("record-modifier" "Records.html#index-record_002dmodifier-1504")
	("record-predicate" "Records.html#index-record_002dpredicate-1502")
	("record-type-descriptor" "Records.html#index-record_002dtype_002ddescriptor-1507")
	("record-type-dispatch-tag" "Dispatch-Tags.html#index-record_002dtype_002ddispatch_002dtag-1898")
	("record-type-field-names" "Records.html#index-record_002dtype_002dfield_002dnames-1511")
	("record-type-name" "Records.html#index-record_002dtype_002dname-1510")
	("record-type?" "Records.html#index-record_002dtype_003f-1508")
	("record?" "Records.html#index-record_003f-1505")
	("redisplay-hook" "Subprocess-Options.html#index-redisplay_002dhook-2730")
	("reduce-left" "Reduction-of-Lists.html#index-reduce_002dleft-1279")
	("reduce-right" "Reduction-of-Lists.html#index-reduce_002dright-1280")
	("regexp-group" "Regular_002dexpression-procedures.html#index-regexp_002dgroup-1023")
	("remainder" "Numerical-operations.html#index-remainder-550")
	("remove" "Filtering-Lists.html#index-remove-1225")
	("remove!" "Filtering-Lists.html#index-remove_0021-1230")
	("remove-generic-procedure-generator" "Method-Generators.html#index-remove_002dgeneric_002dprocedure_002dgenerator-1888")
	("remove-generic-procedure-generators" "Method-Generators.html#index-remove_002dgeneric_002dprocedure_002dgenerators-1889")
	("rename-file" "File-Manipulation.html#index-rename_002dfile-2587")
	("resize-window on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-resize_002dwindow-on-win32_002dgraphics_002ddevice-3112")
	("resize-window on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-resize_002dwindow-on-x_002dgraphics_002ddevice-3072")
	("resource-id" "Windows-Types.html#index-resource_002did-3152")
	("restart/effector" "The-Named-Restart-Abstraction.html#index-restart_002feffector-2884")
	("restart/interactor" "Finding-and-Invoking-General-Restart-Code.html#index-restart_002finteractor-2880")
	("restart/interactor" "The-Named-Restart-Abstraction.html#index-restart_002finteractor-2887")
	("restart/name" "The-Named-Restart-Abstraction.html#index-restart_002fname-2882")
	("restart?" "The-Named-Restart-Abstraction.html#index-restart_003f-2881")
	("retry" "Invoking-Standard-Restart-Code.html#index-retry-2864")
	("retry" "Restarts.html#index-retry-2848")
	("retry" "Invoking-Standard-Restart-Code.html#index-retry-2867")
	("reverse" "Miscellaneous-List-Operations.html#index-reverse-1293")
	("reverse!" "Miscellaneous-List-Operations.html#index-reverse_0021-1295")
	("reverse-string" "Modification-of-Strings.html#index-reverse_002dstring-1061")
	("reverse-string!" "Modification-of-Strings.html#index-reverse_002dstring_0021-1063")
	("reverse-substring" "Modification-of-Strings.html#index-reverse_002dsubstring-1062")
	("reverse-substring!" "Modification-of-Strings.html#index-reverse_002dsubstring_0021-1064")
	("rexp*" "REXP-abstraction.html#index-rexp_002a-1044")
	("rexp+" "REXP-abstraction.html#index-rexp_002b-1045")
	("rexp->regexp" "REXP-abstraction.html#index-rexp_002d_003eregexp-1026")
	("rexp-alternatives" "REXP-abstraction.html#index-rexp_002dalternatives-1042")
	("rexp-any-char" "REXP-abstraction.html#index-rexp_002dany_002dchar-1028")
	("rexp-case-fold" "REXP-abstraction.html#index-rexp_002dcase_002dfold-1047")
	("rexp-compile" "REXP-abstraction.html#index-rexp_002dcompile-1027")
	("rexp-group" "REXP-abstraction.html#index-rexp_002dgroup-1043")
	("rexp-line-end" "REXP-abstraction.html#index-rexp_002dline_002dend-1030")
	("rexp-line-start" "REXP-abstraction.html#index-rexp_002dline_002dstart-1029")
	("rexp-not-syntax-char" "REXP-abstraction.html#index-rexp_002dnot_002dsyntax_002dchar-1040")
	("rexp-not-word-char" "REXP-abstraction.html#index-rexp_002dnot_002dword_002dchar-1038")
	("rexp-not-word-edge" "REXP-abstraction.html#index-rexp_002dnot_002dword_002dedge-1034")
	("rexp-optional" "REXP-abstraction.html#index-rexp_002doptional-1046")
	("rexp-sequence" "REXP-abstraction.html#index-rexp_002dsequence-1041")
	("rexp-string-end" "REXP-abstraction.html#index-rexp_002dstring_002dend-1032")
	("rexp-string-start" "REXP-abstraction.html#index-rexp_002dstring_002dstart-1031")
	("rexp-syntax-char" "REXP-abstraction.html#index-rexp_002dsyntax_002dchar-1039")
	("rexp-word-char" "REXP-abstraction.html#index-rexp_002dword_002dchar-1037")
	("rexp-word-edge" "REXP-abstraction.html#index-rexp_002dword_002dedge-1033")
	("rexp-word-end" "REXP-abstraction.html#index-rexp_002dword_002dend-1036")
	("rexp-word-start" "REXP-abstraction.html#index-rexp_002dword_002dstart-1035")
	("rexp?" "REXP-abstraction.html#index-rexp_003f-1025")
	("round" "Numerical-operations.html#index-round-560")
	("round->exact" "Numerical-operations.html#index-round_002d_003eexact-564")
	("rsc-macro-transformer" "SC-Transformer-Definition.html#index-rsc_002dmacro_002dtransformer-392")
	("run-shell-command" "Subprocess-Procedures.html#index-run_002dshell_002dcommand-2719")
	("run-synchronous-subprocess" "Subprocess-Procedures.html#index-run_002dsynchronous_002dsubprocess-2720")
	("runtime" "Machine-Time.html#index-runtime-2714")
	("safe-accessors" "Structure-Definitions.html#index-safe_002daccessors-362")
	("save-bitmap on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-save_002dbitmap-on-win32_002dgraphics_002ddevice-3109")
	("sc-macro-transformer" "SC-Transformer-Definition.html#index-sc_002dmacro_002dtransformer-386")
	("scalar-values->char-set" "Character-Sets.html#index-scalar_002dvalues_002d_003echar_002dset-808")
	("scheme-subprocess-environment" "Subprocess-Options.html#index-scheme_002dsubprocess_002denvironment-2732")
	("second" "Selecting-List-Components.html#index-second-1200")
	("seq" "_002aMatcher.html#index-seq-2283")
	("seq" "_002aParser.html#index-seq-2297")
	("sequence" "Sequencing.html#index-sequence-334")
	("set!" "Assignments.html#index-set_0021-269")
	("set!" "Top_002dLevel-Definitions.html#index-set_0021-255")
	("set-apply-hook-extra!" "Application-Hooks.html#index-set_002dapply_002dhook_002dextra_0021-1868")
	("set-apply-hook-procedure!" "Application-Hooks.html#index-set_002dapply_002dhook_002dprocedure_0021-1866")
	("set-background-color" "Custom-Operations-for-Win32-Graphics.html#index-set_002dbackground_002dcolor-3095")
	("set-background-color on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-set_002dbackground_002dcolor-on-win32_002dgraphics_002ddevice-3093")
	("set-background-color on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-set_002dbackground_002dcolor-on-x_002dgraphics_002ddevice-3048")
	("set-border-color on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-set_002dborder_002dcolor-on-x_002dgraphics_002ddevice-3050")
	("set-border-width on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-set_002dborder_002dwidth-on-x_002dgraphics_002ddevice-3065")
	("set-car!" "Pairs.html#index-set_002dcar_0021-1129")
	("set-cdr!" "Lists.html#index-set_002dcdr_0021-1106")
	("set-cdr!" "Pairs.html#index-set_002dcdr_0021-1130")
	("set-cell-contents!" "Cells.html#index-set_002dcell_002dcontents_0021-1495")
	("set-current-input-port!" "Ports.html#index-set_002dcurrent_002dinput_002dport_0021-1988")
	("set-current-output-port!" "Ports.html#index-set_002dcurrent_002doutput_002dport_0021-1989")
	("set-current-parser-macros!" "Parser_002dlanguage-Macros.html#index-set_002dcurrent_002dparser_002dmacros_0021-2315")
	("set-entity-extra!" "Application-Hooks.html#index-set_002dentity_002dextra_0021-1875")
	("set-entity-procedure!" "Application-Hooks.html#index-set_002dentity_002dprocedure_0021-1873")
	("set-ephemeron-datum!" "Ephemerons.html#index-set_002dephemeron_002ddatum_0021-1584")
	("set-ephemeron-key!" "Ephemerons.html#index-set_002dephemeron_002dkey_0021-1583")
	("set-file-modes!" "File-Manipulation.html#index-set_002dfile_002dmodes_0021-2624")
	("set-file-times!" "File-Manipulation.html#index-set_002dfile_002dtimes_0021-2641")
	("set-font on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-set_002dfont-on-win32_002dgraphics_002ddevice-3115")
	("set-font on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-set_002dfont-on-x_002dgraphics_002ddevice-3068")
	("set-foreground-color" "Custom-Operations-for-Win32-Graphics.html#index-set_002dforeground_002dcolor-3096")
	("set-foreground-color on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-set_002dforeground_002dcolor-on-win32_002dgraphics_002ddevice-3094")
	("set-foreground-color on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-set_002dforeground_002dcolor-on-x_002dgraphics_002ddevice-3049")
	("set-generic-procedure-default-generator!" "Method-Generators.html#index-set_002dgeneric_002dprocedure_002ddefault_002dgenerator_0021-1892")
	("set-hash-table/rehash-size!" "Resizing-of-Hash-Tables.html#index-set_002dhash_002dtable_002frehash_002dsize_0021-1696")
	("set-hash-table/rehash-threshold!" "Resizing-of-Hash-Tables.html#index-set_002dhash_002dtable_002frehash_002dthreshold_0021-1698")
	("set-input-buffer-size on input port" "Input-Port-Operations.html#index-set_002dinput_002dbuffer_002dsize-on-input-port-2192")
	("set-interaction-i/o-port!" "Ports.html#index-set_002dinteraction_002di_002fo_002dport_0021-1992")
	("set-internal-border-width on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-set_002dinternal_002dborder_002dwidth-on-x_002dgraphics_002ddevice-3066")
	("set-line-width on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-set_002dline_002dwidth-on-win32_002dgraphics_002ddevice-3113")
	("set-mouse-color on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-set_002dmouse_002dcolor-on-x_002dgraphics_002ddevice-3051")
	("set-mouse-shape on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-set_002dmouse_002dshape-on-x_002dgraphics_002ddevice-3069")
	("set-notification-output-port!" "Ports.html#index-set_002dnotification_002doutput_002dport_0021-1990")
	("set-output-buffer-size on output port" "Output-Port-Operations.html#index-set_002doutput_002dbuffer_002dsize-on-output-port-2209")
	("set-parser-buffer-pointer!" "Parser-Buffers.html#index-set_002dparser_002dbuffer_002dpointer_0021-2242")
	("set-port/state!" "Constructors-and-Accessors-for-Ports.html#index-set_002dport_002fstate_0021-2166")
	("set-record-type-unparser-method!" "Structure-Definitions.html#index-set_002drecord_002dtype_002dunparser_002dmethod_0021-353")
	("set-record-type-unparser-method!" "Custom-Output.html#index-set_002drecord_002dtype_002dunparser_002dmethod_0021-2128")
	("set-string-length!" "Variable_002dLength-Strings.html#index-set_002dstring_002dlength_0021-1069")
	("set-trace-output-port!" "Ports.html#index-set_002dtrace_002doutput_002dport_0021-1991")
	("set-window-name on win32-graphics-device" "Custom-Operations-for-Win32-Graphics.html#index-set_002dwindow_002dname-on-win32_002dgraphics_002ddevice-3114")
	("set-working-directory-pathname!" "Working-Directory.html#index-set_002dworking_002ddirectory_002dpathname_0021-2575")
	("set-xml-!attlist-definitions!" "XML-Structure.html#index-set_002dxml_002d_0021attlist_002ddefinitions_0021-2433")
	("set-xml-!attlist-name!" "XML-Structure.html#index-set_002dxml_002d_0021attlist_002dname_0021-2432")
	("set-xml-!element-content-type!" "XML-Structure.html#index-set_002dxml_002d_0021element_002dcontent_002dtype_0021-2425")
	("set-xml-!element-name!" "XML-Structure.html#index-set_002dxml_002d_0021element_002dname_0021-2424")
	("set-xml-!entity-name!" "XML-Structure.html#index-set_002dxml_002d_0021entity_002dname_0021-2440")
	("set-xml-!entity-value!" "XML-Structure.html#index-set_002dxml_002d_0021entity_002dvalue_0021-2441")
	("set-xml-!notation-id!" "XML-Structure.html#index-set_002dxml_002d_0021notation_002did_0021-2467")
	("set-xml-!notation-name!" "XML-Structure.html#index-set_002dxml_002d_0021notation_002dname_0021-2466")
	("set-xml-declaration-encoding!" "XML-Structure.html#index-set_002dxml_002ddeclaration_002dencoding_0021-2388")
	("set-xml-declaration-standalone!" "XML-Structure.html#index-set_002dxml_002ddeclaration_002dstandalone_0021-2389")
	("set-xml-declaration-version!" "XML-Structure.html#index-set_002dxml_002ddeclaration_002dversion_0021-2387")
	("set-xml-document-declaration!" "XML-Structure.html#index-set_002dxml_002ddocument_002ddeclaration_0021-2374")
	("set-xml-document-dtd!" "XML-Structure.html#index-set_002dxml_002ddocument_002ddtd_0021-2376")
	("set-xml-document-misc-1!" "XML-Structure.html#index-set_002dxml_002ddocument_002dmisc_002d1_0021-2375")
	("set-xml-document-misc-2!" "XML-Structure.html#index-set_002dxml_002ddocument_002dmisc_002d2_0021-2377")
	("set-xml-document-misc-3!" "XML-Structure.html#index-set_002dxml_002ddocument_002dmisc_002d3_0021-2379")
	("set-xml-document-root!" "XML-Structure.html#index-set_002dxml_002ddocument_002droot_0021-2378")
	("set-xml-dtd-external!" "XML-Structure.html#index-set_002dxml_002ddtd_002dexternal_0021-2416")
	("set-xml-dtd-internal!" "XML-Structure.html#index-set_002dxml_002ddtd_002dinternal_0021-2417")
	("set-xml-dtd-root!" "XML-Structure.html#index-set_002dxml_002ddtd_002droot_0021-2415")
	("set-xml-element-attributes!" "XML-Structure.html#index-set_002dxml_002delement_002dattributes_0021-2398")
	("set-xml-element-content!" "XML-Structure.html#index-set_002dxml_002delement_002dcontent_0021-2399")
	("set-xml-element-name!" "XML-Structure.html#index-set_002dxml_002delement_002dname_0021-2397")
	("set-xml-external-id-id!" "XML-Structure.html#index-set_002dxml_002dexternal_002did_002did_0021-2474")
	("set-xml-external-id-uri!" "XML-Structure.html#index-set_002dxml_002dexternal_002did_002duri_0021-2475")
	("set-xml-parameter-!entity-name!" "XML-Structure.html#index-set_002dxml_002dparameter_002d_0021entity_002dname_0021-2448")
	("set-xml-parameter-!entity-value!" "XML-Structure.html#index-set_002dxml_002dparameter_002d_0021entity_002dvalue_0021-2449")
	("set-xml-processing-instructions-name!" "XML-Structure.html#index-set_002dxml_002dprocessing_002dinstructions_002dname_0021-2406")
	("set-xml-processing-instructions-text!" "XML-Structure.html#index-set_002dxml_002dprocessing_002dinstructions_002dtext_0021-2407")
	("set-xml-unparsed-!entity-id!" "XML-Structure.html#index-set_002dxml_002dunparsed_002d_0021entity_002did_0021-2458")
	("set-xml-unparsed-!entity-name!" "XML-Structure.html#index-set_002dxml_002dunparsed_002d_0021entity_002dname_0021-2457")
	("set-xml-unparsed-!entity-notation!" "XML-Structure.html#index-set_002dxml_002dunparsed_002d_0021entity_002dnotation_0021-2459")
	("seventh" "Selecting-List-Components.html#index-seventh-1205")
	("sexp" "_002aParser.html#index-sexp-2305")
	("sexp" "_002aMatcher.html#index-sexp-2288")
	("shell-file-name" "Subprocess-Options.html#index-shell_002dfile_002dname-2735")
	("short" "Windows-Types.html#index-short-3134")
	("signal-condition" "Condition-Handling.html#index-signal_002dcondition-2811")
	("signal-condition" "Condition-Signalling.html#index-signal_002dcondition-2779")
	("signal-condition" "Error-System.html#index-signal_002dcondition-2767")
	("signed-integer->bit-string" "Integer-Conversions-of-Bit-Strings.html#index-signed_002dinteger_002d_003ebit_002dstring-1416")
	("simplest-exact-rational" "Numerical-operations.html#index-simplest_002dexact_002drational-570")
	("simplest-rational" "Numerical-operations.html#index-simplest_002drational-569")
	("sin" "Numerical-operations.html#index-sin-573")
	("singleton-wt-tree" "Construction-of-Weight_002dBalanced-Trees.html#index-singleton_002dwt_002dtree-1766")
	("sixth" "Selecting-List-Components.html#index-sixth-1204")
	("soft-link-file" "File-Manipulation.html#index-soft_002dlink_002dfile-2596")
	("sort" "Miscellaneous-List-Operations.html#index-sort-1296")
	("sort!" "Modifying-Vectors.html#index-sort_0021-1357")
	("source->parser-buffer" "Parser-Buffers.html#index-source_002d_003eparser_002dbuffer-2235")
	("sqrt" "Implementation-restrictions.html#index-sqrt-444")
	("sqrt" "Numerical-operations.html#index-sqrt-582")
	("standard-error-handler" "Condition-Handling.html#index-standard_002derror_002dhandler-2817")
	("standard-error-hook" "Condition-Handling.html#index-standard_002derror_002dhook-2822")
	("standard-unparser-method" "Custom-Output.html#index-standard_002dunparser_002dmethod-2133")
	("standard-warning-handler" "Condition-Handling.html#index-standard_002dwarning_002dhandler-2827")
	("standard-warning-hook" "Condition-Handling.html#index-standard_002dwarning_002dhook-2828")
	("store-value" "Restarts.html#index-store_002dvalue-2849")
	("store-value" "Invoking-Standard-Restart-Code.html#index-store_002dvalue-2865")
	("stream" "Streams.html#index-stream-1529")
	("stream->list" "Streams.html#index-stream_002d_003elist-1533")
	("stream-car" "Streams.html#index-stream_002dcar-1538")
	("stream-cdr" "Streams.html#index-stream_002dcdr-1541")
	("stream-first" "Streams.html#index-stream_002dfirst-1539")
	("stream-head" "Streams.html#index-stream_002dhead-1553")
	("stream-length" "Streams.html#index-stream_002dlength-1548")
	("stream-map" "Streams.html#index-stream_002dmap-1555")
	("stream-null?" "Streams.html#index-stream_002dnull_003f-1545")
	("stream-pair?" "Streams.html#index-stream_002dpair_003f-1536")
	("stream-ref" "Streams.html#index-stream_002dref-1550")
	("stream-rest" "Streams.html#index-stream_002drest-1542")
	("stream-tail" "Streams.html#index-stream_002dtail-1554")
	("string" "Construction-of-Strings.html#index-string-895")
	("string" "_002aMatcher.html#index-string-2278")
	("string" "Windows-Types.html#index-string-3138")
	("string->char-set" "Character-Sets.html#index-string_002d_003echar_002dset-807")
	("string->decoded-time" "Time_002dFormat-Conversion.html#index-string_002d_003edecoded_002dtime-2699")
	("string->file-time" "Time_002dFormat-Conversion.html#index-string_002d_003efile_002dtime-2700")
	("string->list" "Construction-of-Strings.html#index-string_002d_003elist-898")
	("string->list" "Construction-of-Lists.html#index-string_002d_003elist-1176")
	("string->number" "Numerical-input-and-output.html#index-string_002d_003enumber-598")
	("string->parser-buffer" "Parser-Buffers.html#index-string_002d_003eparser_002dbuffer-2234")
	("string->symbol" "Symbols.html#index-string_002d_003esymbol-1473")
	("string->uninterned-symbol" "Symbols.html#index-string_002d_003euninterned_002dsymbol-1475")
	("string->universal-time" "Time_002dFormat-Conversion.html#index-string_002d_003euniversal_002dtime-2698")
	("string->wide-string" "Wide-Strings.html#index-string_002d_003ewide_002dstring-832")
	("string->xml" "XML-Input.html#index-string_002d_003exml-2326")
	("string-append" "Cutting-and-Pasting-Strings.html#index-string_002dappend-957")
	("string-capitalize" "Alphabetic-Case-in-Strings.html#index-string_002dcapitalize-946")
	("string-capitalize!" "Alphabetic-Case-in-Strings.html#index-string_002dcapitalize_0021-947")
	("string-capitalized?" "Alphabetic-Case-in-Strings.html#index-string_002dcapitalized_003f-940")
	("string-ci" "_002aMatcher.html#index-string_002dci-2279")
	("string-ci<=?" "Comparison-of-Strings.html#index-string_002dci_003c_003d_003f-926")
	("string-ci<?" "Comparison-of-Strings.html#index-string_002dci_003c_003f-923")
	("string-ci=?" "Comparison-of-Strings.html#index-string_002dci_003d_003f-915")
	("string-ci>=?" "Comparison-of-Strings.html#index-string_002dci_003e_003d_003f-927")
	("string-ci>?" "Comparison-of-Strings.html#index-string_002dci_003e_003f-925")
	("string-compare" "Comparison-of-Strings.html#index-string_002dcompare-928")
	("string-compare-ci" "Comparison-of-Strings.html#index-string_002dcompare_002dci-929")
	("string-copy" "Construction-of-Strings.html#index-string_002dcopy-899")
	("string-downcase" "Alphabetic-Case-in-Strings.html#index-string_002ddowncase-949")
	("string-downcase!" "Alphabetic-Case-in-Strings.html#index-string_002ddowncase_0021-950")
	("string-fill!" "Modification-of-Strings.html#index-string_002dfill_0021-1056")
	("string-find-next-char" "Searching-Strings.html#index-string_002dfind_002dnext_002dchar-981")
	("string-find-next-char-ci" "Searching-Strings.html#index-string_002dfind_002dnext_002dchar_002dci-983")
	("string-find-next-char-in-set" "Searching-Strings.html#index-string_002dfind_002dnext_002dchar_002din_002dset-985")
	("string-find-previous-char" "Searching-Strings.html#index-string_002dfind_002dprevious_002dchar-987")
	("string-find-previous-char-ci" "Searching-Strings.html#index-string_002dfind_002dprevious_002dchar_002dci-989")
	("string-find-previous-char-in-set" "Searching-Strings.html#index-string_002dfind_002dprevious_002dchar_002din_002dset-991")
	("string-hash" "Comparison-of-Strings.html#index-string_002dhash-930")
	("string-hash" "Symbols.html#index-string_002dhash-1484")
	("string-hash-mod" "Construction-of-Hash-Tables.html#index-string_002dhash_002dmod-1672")
	("string-hash-mod" "Comparison-of-Strings.html#index-string_002dhash_002dmod-931")
	("string-head" "Cutting-and-Pasting-Strings.html#index-string_002dhead-960")
	("string-is-xml-name?" "XML-Names.html#index-string_002dis_002dxml_002dname_003f-2362")
	("string-is-xml-nmtoken?" "XML-Names.html#index-string_002dis_002dxml_002dnmtoken_003f-2363")
	("string-length" "Selecting-String-Components.html#index-string_002dlength-905")
	("string-length" "Variable_002dLength-Strings.html#index-string_002dlength-1068")
	("string-length" "Implementation-restrictions.html#index-string_002dlength-442")
	("string-lower-case?" "Alphabetic-Case-in-Strings.html#index-string_002dlower_002dcase_003f-944")
	("string-match-backward" "Matching-Strings.html#index-string_002dmatch_002dbackward-998")
	("string-match-backward-ci" "Matching-Strings.html#index-string_002dmatch_002dbackward_002dci-1000")
	("string-match-forward" "Matching-Strings.html#index-string_002dmatch_002dforward-994")
	("string-match-forward-ci" "Matching-Strings.html#index-string_002dmatch_002dforward_002dci-996")
	("string-maximum-length" "Variable_002dLength-Strings.html#index-string_002dmaximum_002dlength-1067")
	("string-null?" "Selecting-String-Components.html#index-string_002dnull_003f-906")
	("string-pad-left" "Cutting-and-Pasting-Strings.html#index-string_002dpad_002dleft-962")
	("string-pad-right" "Cutting-and-Pasting-Strings.html#index-string_002dpad_002dright-963")
	("string-prefix-ci?" "Matching-Strings.html#index-string_002dprefix_002dci_003f-1004")
	("string-prefix?" "Matching-Strings.html#index-string_002dprefix_003f-1002")
	("string-ref" "Selecting-String-Components.html#index-string_002dref-909")
	("string-ref" "Byte-Vectors.html#index-string_002dref-1072")
	("string-ref" "Storage-Model.html#index-string_002dref-113")
	("string-replace" "Modification-of-Strings.html#index-string_002dreplace-1052")
	("string-replace!" "Modification-of-Strings.html#index-string_002dreplace_0021-1054")
	("string-search-all" "Searching-Strings.html#index-string_002dsearch_002dall-978")
	("string-search-backward" "Searching-Strings.html#index-string_002dsearch_002dbackward-976")
	("string-search-forward" "Searching-Strings.html#index-string_002dsearch_002dforward-974")
	("string-set!" "Selecting-String-Components.html#index-string_002dset_0021-910")
	("string-set!" "Storage-Model.html#index-string_002dset_0021-110")
	("string-set!" "Symbols.html#index-string_002dset_0021-1468")
	("string-suffix-ci?" "Matching-Strings.html#index-string_002dsuffix_002dci_003f-1009")
	("string-suffix?" "Matching-Strings.html#index-string_002dsuffix_003f-1007")
	("string-tail" "Cutting-and-Pasting-Strings.html#index-string_002dtail-961")
	("string-trim" "Cutting-and-Pasting-Strings.html#index-string_002dtrim-966")
	("string-trim-left" "Cutting-and-Pasting-Strings.html#index-string_002dtrim_002dleft-967")
	("string-trim-right" "Cutting-and-Pasting-Strings.html#index-string_002dtrim_002dright-968")
	("string-upcase" "Alphabetic-Case-in-Strings.html#index-string_002dupcase-952")
	("string-upcase!" "Alphabetic-Case-in-Strings.html#index-string_002dupcase_0021-953")
	("string-upper-case?" "Alphabetic-Case-in-Strings.html#index-string_002dupper_002dcase_003f-942")
	("string-wt-type" "Construction-of-Weight_002dBalanced-Trees.html#index-string_002dwt_002dtype-1764")
	("string<=?" "Comparison-of-Strings.html#index-string_003c_003d_003f-921")
	("string<?" "Comparison-of-Strings.html#index-string_003c_003f-918")
	("string=?" "Comparison-of-Strings.html#index-string_003d_003f-913")
	("string=?" "Equivalence-Predicates.html#index-string_003d_003f-423")
	("string=?" "Comparison-of-Strings.html#index-string_003d_003f-933")
	("string=?" "Construction-of-Hash-Tables.html#index-string_003d_003f-1663")
	("string=?" "Symbols.html#index-string_003d_003f-1453")
	("string=?" "Equivalence-Predicates.html#index-string_003d_003f-427")
	("string>=?" "Comparison-of-Strings.html#index-string_003e_003d_003f-922")
	("string>?" "Comparison-of-Strings.html#index-string_003e_003f-920")
	("string?" "Selecting-String-Components.html#index-string_003f-903")
	("strong-hash-table/constructor" "Construction-of-Hash-Tables.html#index-strong_002dhash_002dtable_002fconstructor-1664")
	("sublist" "Cutting-and-Pasting-Lists.html#index-sublist-1211")
	("substring" "Cutting-and-Pasting-Strings.html#index-substring-959")
	("substring->list" "Construction-of-Lists.html#index-substring_002d_003elist-1177")
	("substring->parser-buffer" "Parser-Buffers.html#index-substring_002d_003eparser_002dbuffer-2233")
	("substring-capitalize!" "Alphabetic-Case-in-Strings.html#index-substring_002dcapitalize_0021-948")
	("substring-capitalized?" "Alphabetic-Case-in-Strings.html#index-substring_002dcapitalized_003f-941")
	("substring-ci<?" "Comparison-of-Strings.html#index-substring_002dci_003c_003f-924")
	("substring-ci=?" "Comparison-of-Strings.html#index-substring_002dci_003d_003f-916")
	("substring-downcase!" "Alphabetic-Case-in-Strings.html#index-substring_002ddowncase_0021-951")
	("substring-fill!" "Modification-of-Strings.html#index-substring_002dfill_0021-1057")
	("substring-find-next-char" "Searching-Strings.html#index-substring_002dfind_002dnext_002dchar-982")
	("substring-find-next-char-ci" "Searching-Strings.html#index-substring_002dfind_002dnext_002dchar_002dci-984")
	("substring-find-next-char-in-set" "Searching-Strings.html#index-substring_002dfind_002dnext_002dchar_002din_002dset-986")
	("substring-find-previous-char" "Searching-Strings.html#index-substring_002dfind_002dprevious_002dchar-988")
	("substring-find-previous-char-ci" "Searching-Strings.html#index-substring_002dfind_002dprevious_002dchar_002dci-990")
	("substring-find-previous-char-in-set" "Searching-Strings.html#index-substring_002dfind_002dprevious_002dchar_002din_002dset-992")
	("substring-lower-case?" "Alphabetic-Case-in-Strings.html#index-substring_002dlower_002dcase_003f-945")
	("substring-match-backward" "Matching-Strings.html#index-substring_002dmatch_002dbackward-999")
	("substring-match-backward-ci" "Matching-Strings.html#index-substring_002dmatch_002dbackward_002dci-1001")
	("substring-match-forward" "Matching-Strings.html#index-substring_002dmatch_002dforward-995")
	("substring-match-forward-ci" "Matching-Strings.html#index-substring_002dmatch_002dforward_002dci-997")
	("substring-move-left!" "Modification-of-Strings.html#index-substring_002dmove_002dleft_0021-1058")
	("substring-move-right!" "Modification-of-Strings.html#index-substring_002dmove_002dright_0021-1059")
	("substring-prefix-ci?" "Matching-Strings.html#index-substring_002dprefix_002dci_003f-1005")
	("substring-prefix?" "Matching-Strings.html#index-substring_002dprefix_003f-1003")
	("substring-replace" "Modification-of-Strings.html#index-substring_002dreplace-1053")
	("substring-replace!" "Modification-of-Strings.html#index-substring_002dreplace_0021-1055")
	("substring-search-all" "Searching-Strings.html#index-substring_002dsearch_002dall-979")
	("substring-search-backward" "Searching-Strings.html#index-substring_002dsearch_002dbackward-977")
	("substring-search-forward" "Searching-Strings.html#index-substring_002dsearch_002dforward-975")
	("substring-suffix-ci?" "Matching-Strings.html#index-substring_002dsuffix_002dci_003f-1010")
	("substring-suffix?" "Matching-Strings.html#index-substring_002dsuffix_003f-1008")
	("substring-upcase!" "Alphabetic-Case-in-Strings.html#index-substring_002dupcase_0021-954")
	("substring-upper-case?" "Alphabetic-Case-in-Strings.html#index-substring_002dupper_002dcase_003f-943")
	("substring<?" "Comparison-of-Strings.html#index-substring_003c_003f-919")
	("substring=?" "Comparison-of-Strings.html#index-substring_003d_003f-914")
	("substring?" "Searching-Strings.html#index-substring_003f-980")
	("subvector" "Cutting-Vectors.html#index-subvector-1347")
	("subvector->list" "Construction-of-Lists.html#index-subvector_002d_003elist-1173")
	("subvector-fill!" "Modifying-Vectors.html#index-subvector_002dfill_0021-1354")
	("subvector-move-left!" "Modifying-Vectors.html#index-subvector_002dmove_002dleft_0021-1355")
	("subvector-move-right!" "Modifying-Vectors.html#index-subvector_002dmove_002dright_0021-1356")
	("symbol->string" "Symbols.html#index-symbol_002d_003estring-1464")
	("symbol->string" "Equivalence-Predicates.html#index-symbol_002d_003estring-428")
	("symbol->string" "Storage-Model.html#index-symbol_002d_003estring-118")
	("symbol-append" "Symbols.html#index-symbol_002dappend-1479")
	("symbol-hash" "Symbols.html#index-symbol_002dhash-1482")
	("symbol-hash-mod" "Symbols.html#index-symbol_002dhash_002dmod-1485")
	("symbol<?" "Symbols.html#index-symbol_003c_003f-1486")
	("symbol?" "Symbols.html#index-symbol_003f-1462")
	("syntax-rules" "Pattern-Language.html#index-syntax_002drules-377")
	("system-clock" "Machine-Time.html#index-system_002dclock-2713")
	("system-global-environment" "Environment-Variables.html#index-system_002dglobal_002denvironment-1931")
	("system-library-directory-pathname" "Miscellaneous-Pathnames.html#index-system_002dlibrary_002ddirectory_002dpathname-2564")
	("system-library-pathname" "Miscellaneous-Pathnames.html#index-system_002dlibrary_002dpathname-2561")
	("t" "Booleans.html#index-t-1431")
	("tan" "Numerical-operations.html#index-tan-575")
	("tcp-server-connection-accept" "TCP-Sockets.html#index-tcp_002dserver_002dconnection_002daccept-2745")
	("template" "Entry-Format.html#index-g_t_0040var_007btemplate_007d-39")
	("temporary-directory-pathname" "File-Manipulation.html#index-temporary_002ddirectory_002dpathname-2607")
	("temporary-file-pathname" "File-Manipulation.html#index-temporary_002dfile_002dpathname-2606")
	("tenth" "Selecting-List-Components.html#index-tenth-1208")
	("the-environment" "Top_002dlevel-Environments.html#index-the_002denvironment-1940")
	("there-exists?" "Reduction-of-Lists.html#index-there_002dexists_003f-1284")
	("third" "Selecting-List-Components.html#index-third-1201")
	("thunk?" "Arity.html#index-thunk_003f-1835")
	("time-zone->string" "External-Representation-of-Time.html#index-time_002dzone_002d_003estring-2707")
	("time-zone?" "Decoded-Time.html#index-time_002dzone_003f-2683")
	("top-level-environment?" "Top_002dlevel-Environments.html#index-top_002dlevel_002denvironment_003f-1943")
	("trace-output-port" "Ports.html#index-trace_002doutput_002dport-1981")
	("transform" "_002aParser.html#index-transform-2302")
	("tree-copy" "Pairs.html#index-tree_002dcopy-1160")
	("true" "Booleans.html#index-true-1434")
	("truncate" "Numerical-operations.html#index-truncate-559")
	("truncate->exact" "Numerical-operations.html#index-truncate_002d_003eexact-563")
	("type" "Structure-Definitions.html#index-type-360")
	("type-descriptor" "Structure-Definitions.html#index-type_002ddescriptor-358")
	("uint" "Windows-Types.html#index-uint-3131")
	("ulong" "Windows-Types.html#index-ulong-3133")
	("unbind-variable" "Top_002dlevel-Environments.html#index-unbind_002dvariable-1950")
	("unchecked" "Windows-Types.html#index-unchecked-3127")
	("unhash" "Object-Hashing.html#index-unhash-1710")
	("unicode-char?" "Unicode.html#index-unicode_002dchar_003f-823")
	("unicode-scalar-value?" "Unicode.html#index-unicode_002dscalar_002dvalue_003f-822")
	("universal-time->file-time" "Time_002dFormat-Conversion.html#index-universal_002dtime_002d_003efile_002dtime-2687")
	("universal-time->global-decoded-time" "Time_002dFormat-Conversion.html#index-universal_002dtime_002d_003eglobal_002ddecoded_002dtime-2686")
	("universal-time->global-time-string" "Time_002dFormat-Conversion.html#index-universal_002dtime_002d_003eglobal_002dtime_002dstring-2689")
	("universal-time->local-decoded-time" "Time_002dFormat-Conversion.html#index-universal_002dtime_002d_003elocal_002ddecoded_002dtime-2685")
	("universal-time->local-time-string" "Time_002dFormat-Conversion.html#index-universal_002dtime_002d_003elocal_002dtime_002dstring-2688")
	("unparser/set-tagged-pair-method!" "Custom-Output.html#index-unparser_002fset_002dtagged_002dpair_002dmethod_0021-2130")
	("unparser/set-tagged-vector-method!" "Custom-Output.html#index-unparser_002fset_002dtagged_002dvector_002dmethod_0021-2129")
	("unquote" "Quoting.html#index-unquote-294")
	("unquote" "Lists.html#index-unquote-1111")
	("unquote-splicing" "Lists.html#index-unquote_002dsplicing-1112")
	("unquote-splicing" "Quoting.html#index-unquote_002dsplicing-295")
	("unsigned-integer->bit-string" "Integer-Conversions-of-Bit-Strings.html#index-unsigned_002dinteger_002d_003ebit_002dstring-1414")
	("use-pty?" "Subprocess-Options.html#index-use_002dpty_003f-2734")
	("use-value" "Invoking-Standard-Restart-Code.html#index-use_002dvalue-2866")
	("use-value" "Restarts.html#index-use_002dvalue-2850")
	("user-homedir-pathname" "Miscellaneous-Pathnames.html#index-user_002dhomedir_002dpathname-2559")
	("user-initial-environment" "Environment-Variables.html#index-user_002dinitial_002denvironment-1932")
	("user-initial-environment" "REPL-Environment.html#index-user_002dinitial_002denvironment-1934")
	("user-initial-environment" "Initial-and-Current-Environments.html#index-user_002dinitial_002denvironment-88")
	("user32.dll" "Windows-Foreign-Procedures.html#index-user32_002edll-3160")
	("ushort" "Windows-Types.html#index-ushort-3135")
	("utf16-be-string->wide-string" "Unicode-Representations.html#index-utf16_002dbe_002dstring_002d_003ewide_002dstring-847")
	("utf16-be-string-length" "Unicode-Representations.html#index-utf16_002dbe_002dstring_002dlength-854")
	("utf16-le-string->wide-string" "Unicode-Representations.html#index-utf16_002dle_002dstring_002d_003ewide_002dstring-848")
	("utf16-le-string-length" "Unicode-Representations.html#index-utf16_002dle_002dstring_002dlength-855")
	("utf16-string->wide-string" "Unicode-Representations.html#index-utf16_002dstring_002d_003ewide_002dstring-849")
	("utf16-string-length" "Unicode-Representations.html#index-utf16_002dstring_002dlength-856")
	("utf32-be-string->wide-string" "Unicode-Representations.html#index-utf32_002dbe_002dstring_002d_003ewide_002dstring-850")
	("utf32-be-string-length" "Unicode-Representations.html#index-utf32_002dbe_002dstring_002dlength-857")
	("utf32-le-string->wide-string" "Unicode-Representations.html#index-utf32_002dle_002dstring_002d_003ewide_002dstring-851")
	("utf32-le-string-length" "Unicode-Representations.html#index-utf32_002dle_002dstring_002dlength-858")
	("utf32-string->wide-string" "Unicode-Representations.html#index-utf32_002dstring_002d_003ewide_002dstring-852")
	("utf32-string-length" "Unicode-Representations.html#index-utf32_002dstring_002dlength-859")
	("utf8-string->wide-string" "Unicode-Representations.html#index-utf8_002dstring_002d_003ewide_002dstring-846")
	("utf8-string-length" "Unicode-Representations.html#index-utf8_002dstring_002dlength-853")
	("valid-hash-number?" "Object-Hashing.html#index-valid_002dhash_002dnumber_003f-1713")
	("values" "Continuations.html#index-values-1856")
	("values" "_002aParser.html#index-values-2295")
	("vector" "Construction-of-Vectors.html#index-vector-1317")
	("vector-8b-fill!" "Byte-Vectors.html#index-vector_002d8b_002dfill_0021-1075")
	("vector-8b-find-next-char" "Byte-Vectors.html#index-vector_002d8b_002dfind_002dnext_002dchar-1076")
	("vector-8b-find-next-char-ci" "Byte-Vectors.html#index-vector_002d8b_002dfind_002dnext_002dchar_002dci-1077")
	("vector-8b-find-previous-char" "Byte-Vectors.html#index-vector_002d8b_002dfind_002dprevious_002dchar-1078")
	("vector-8b-find-previous-char-ci" "Byte-Vectors.html#index-vector_002d8b_002dfind_002dprevious_002dchar_002dci-1079")
	("vector-8b-ref" "Byte-Vectors.html#index-vector_002d8b_002dref-1073")
	("vector-8b-set!" "Byte-Vectors.html#index-vector_002d8b_002dset_0021-1074")
	("vector->list" "Construction-of-Vectors.html#index-vector_002d_003elist-1323")
	("vector->list" "Construction-of-Lists.html#index-vector_002d_003elist-1172")
	("vector-binary-search" "Selecting-Vector-Components.html#index-vector_002dbinary_002dsearch-1344")
	("vector-copy" "Construction-of-Vectors.html#index-vector_002dcopy-1319")
	("vector-eighth" "Selecting-Vector-Components.html#index-vector_002deighth-1343")
	("vector-fifth" "Selecting-Vector-Components.html#index-vector_002dfifth-1340")
	("vector-fill!" "Modifying-Vectors.html#index-vector_002dfill_0021-1353")
	("vector-first" "Selecting-Vector-Components.html#index-vector_002dfirst-1336")
	("vector-fourth" "Selecting-Vector-Components.html#index-vector_002dfourth-1339")
	("vector-grow" "Construction-of-Vectors.html#index-vector_002dgrow-1325")
	("vector-head" "Cutting-Vectors.html#index-vector_002dhead-1348")
	("vector-length" "Selecting-Vector-Components.html#index-vector_002dlength-1333")
	("vector-length" "Implementation-restrictions.html#index-vector_002dlength-441")
	("vector-map" "Construction-of-Vectors.html#index-vector_002dmap-1327")
	("vector-ref" "Storage-Model.html#index-vector_002dref-112")
	("vector-ref" "Selecting-Vector-Components.html#index-vector_002dref-1334")
	("vector-second" "Selecting-Vector-Components.html#index-vector_002dsecond-1337")
	("vector-set!" "Selecting-Vector-Components.html#index-vector_002dset_0021-1335")
	("vector-seventh" "Selecting-Vector-Components.html#index-vector_002dseventh-1342")
	("vector-sixth" "Selecting-Vector-Components.html#index-vector_002dsixth-1341")
	("vector-tail" "Cutting-Vectors.html#index-vector_002dtail-1349")
	("vector-third" "Selecting-Vector-Components.html#index-vector_002dthird-1338")
	("vector?" "Selecting-Vector-Components.html#index-vector_003f-1331")
	("warn" "Invoking-Standard-Restart-Code.html#index-warn-2862")
	("warn" "Condition-Signalling.html#index-warn-2783")
	("weak-car" "Weak-Pairs.html#index-weak_002dcar-1565")
	("weak-cdr" "Weak-Pairs.html#index-weak_002dcdr-1569")
	("weak-cons" "Weak-Pairs.html#index-weak_002dcons-1562")
	("weak-hash-table/constructor" "Construction-of-Hash-Tables.html#index-weak_002dhash_002dtable_002fconstructor-1665")
	("weak-pair/car?" "Weak-Pairs.html#index-weak_002dpair_002fcar_003f-1564")
	("weak-pair?" "Weak-Pairs.html#index-weak_002dpair_003f-1560")
	("weak-set-car!" "Weak-Pairs.html#index-weak_002dset_002dcar_0021-1568")
	("weak-set-cdr!" "Weak-Pairs.html#index-weak_002dset_002dcdr_0021-1570")
	("well-formed-scalar-values-list?" "Character-Sets.html#index-well_002dformed_002dscalar_002dvalues_002dlist_003f-810")
	("where" "Prompting.html#index-where-2145")
	("wide-string" "Wide-Strings.html#index-wide_002dstring-828")
	("wide-string->string" "Wide-Strings.html#index-wide_002dstring_002d_003estring-833")
	("wide-string->utf16-be-string" "Unicode-Representations.html#index-wide_002dstring_002d_003eutf16_002dbe_002dstring-861")
	("wide-string->utf16-le-string" "Unicode-Representations.html#index-wide_002dstring_002d_003eutf16_002dle_002dstring-862")
	("wide-string->utf16-string" "Unicode-Representations.html#index-wide_002dstring_002d_003eutf16_002dstring-863")
	("wide-string->utf32-be-string" "Unicode-Representations.html#index-wide_002dstring_002d_003eutf32_002dbe_002dstring-864")
	("wide-string->utf32-le-string" "Unicode-Representations.html#index-wide_002dstring_002d_003eutf32_002dle_002dstring-865")
	("wide-string->utf32-string" "Unicode-Representations.html#index-wide_002dstring_002d_003eutf32_002dstring-866")
	("wide-string->utf8-string" "Unicode-Representations.html#index-wide_002dstring_002d_003eutf8_002dstring-860")
	("wide-string-length" "Wide-Strings.html#index-wide_002dstring_002dlength-829")
	("wide-string-ref" "Wide-Strings.html#index-wide_002dstring_002dref-830")
	("wide-string-set!" "Wide-Strings.html#index-wide_002dstring_002dset_0021-831")
	("wide-string?" "Wide-Strings.html#index-wide_002dstring_003f-826")
	("windows-procedure" "Windows-Foreign-Procedures.html#index-windows_002dprocedure-3162")
	("with-current-parser-macros" "Parser_002dlanguage-Macros.html#index-with_002dcurrent_002dparser_002dmacros-2316")
	("with-current-unparser-state" "Custom-Output.html#index-with_002dcurrent_002dunparser_002dstate-2138")
	("with-input-from-binary-file" "File-Ports.html#index-with_002dinput_002dfrom_002dbinary_002dfile-2035")
	("with-input-from-file" "File-Ports.html#index-with_002dinput_002dfrom_002dfile-2029")
	("with-input-from-port" "Ports.html#index-with_002dinput_002dfrom_002dport-1983")
	("with-input-from-string" "String-Ports.html#index-with_002dinput_002dfrom_002dstring-2045")
	("with-interaction-i/o-port" "Ports.html#index-with_002dinteraction_002di_002fo_002dport-1987")
	("with-notification-output-port" "Ports.html#index-with_002dnotification_002doutput_002dport-1985")
	("with-output-to-binary-file" "File-Ports.html#index-with_002doutput_002dto_002dbinary_002dfile-2036")
	("with-output-to-file" "File-Ports.html#index-with_002doutput_002dto_002dfile-2030")
	("with-output-to-port" "Ports.html#index-with_002doutput_002dto_002dport-1984")
	("with-output-to-string" "String-Ports.html#index-with_002doutput_002dto_002dstring-2050")
	("with-output-to-truncated-string" "String-Ports.html#index-with_002doutput_002dto_002dtruncated_002dstring-2054")
	("with-pointer" "_002aParser.html#index-with_002dpointer-2306")
	("with-pointer" "_002aMatcher.html#index-with_002dpointer-2289")
	("with-restart" "Error-System.html#index-with_002drestart-2769")
	("with-restart" "Establishing-Restart-Code.html#index-with_002drestart-2855")
	("with-restart" "Restarts.html#index-with_002drestart-2840")
	("with-restart" "Finding-and-Invoking-General-Restart-Code.html#index-with_002drestart-2869")
	("with-simple-restart" "Restarts.html#index-with_002dsimple_002drestart-2841")
	("with-simple-restart" "Establishing-Restart-Code.html#index-with_002dsimple_002drestart-2854")
	("with-simple-restart" "Finding-and-Invoking-General-Restart-Code.html#index-with_002dsimple_002drestart-2870")
	("with-timings" "Machine-Time.html#index-with_002dtimings-2715")
	("with-trace-output-port" "Ports.html#index-with_002dtrace_002doutput_002dport-1986")
	("with-working-directory-pathname" "Working-Directory.html#index-with_002dworking_002ddirectory_002dpathname-2579")
	("withdraw-window on x-graphics-device" "Custom-Operations-on-X-Graphics-Devices.html#index-withdraw_002dwindow-on-x_002dgraphics_002ddevice-3071")
	("within-continuation" "Continuations.html#index-within_002dcontinuation-1849")
	("word" "Windows-Types.html#index-word-3136")
	("working-directory" "Subprocess-Options.html#index-working_002ddirectory-2733")
	("working-directory-pathname" "Working-Directory.html#index-working_002ddirectory_002dpathname-2573")
	("write" "Symbols.html#index-write-1460")
	("write" "Error-Messages.html#index-write-2798")
	("write" "Symbols.html#index-write-1457")
	("write" "Custom-Output.html#index-write-2135")
	("write" "External-Representations.html#index-write-108")
	("write" "Output-Procedures.html#index-write-2092")
	("write-char" "Output-Procedures.html#index-write_002dchar-2086")
	("write-char" "Ports.html#index-write_002dchar-1963")
	("write-char" "Entry-Format.html#index-write_002dchar-56")
	("write-char on output port" "Output-Port-Operations.html#index-write_002dchar-on-output-port-2194")
	("write-condition-report" "Condition-State.html#index-write_002dcondition_002dreport-2914")
	("write-condition-report" "Simple-Condition-Instance-Operations.html#index-write_002dcondition_002dreport-2922")
	("write-condition-report" "Condition-Handling.html#index-write_002dcondition_002dreport-2831")
	("write-dib" "DIB-procedures.html#index-write_002ddib-3169")
	("write-line" "Output-Procedures.html#index-write_002dline-2100")
	("write-restart-report" "The-Named-Restart-Abstraction.html#index-write_002drestart_002dreport-2889")
	("write-string" "Custom-Output.html#index-write_002dstring-2136")
	("write-string" "Output-Procedures.html#index-write_002dstring-2088")
	("write-string" "Format.html#index-write_002dstring-2123")
	("write-substring" "Output-Procedures.html#index-write_002dsubstring-2090")
	("write-substring on output port" "Output-Port-Operations.html#index-write_002dsubstring-on-output-port-2196")
	("write-to-string" "String-Ports.html#index-write_002dto_002dstring-2055")
	("write-xml" "XML-Output.html#index-write_002dxml-2329")
	("write-xml-file" "XML-Output.html#index-write_002dxml_002dfile-2330")
	("wt-tree/add" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fadd-1771")
	("wt-tree/add!" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fadd_0021-1772")
	("wt-tree/delete" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fdelete-1775")
	("wt-tree/delete!" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fdelete_0021-1776")
	("wt-tree/delete-min" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fdelete_002dmin-1794")
	("wt-tree/delete-min!" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fdelete_002dmin_0021-1795")
	("wt-tree/difference" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fdifference-1781")
	("wt-tree/empty?" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fempty_003f-1769")
	("wt-tree/fold" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002ffold-1784")
	("wt-tree/for-each" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002ffor_002deach-1785")
	("wt-tree/index" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002findex-1787")
	("wt-tree/index-datum" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002findex_002ddatum-1788")
	("wt-tree/index-pair" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002findex_002dpair-1789")
	("wt-tree/intersection" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fintersection-1780")
	("wt-tree/lookup" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002flookup-1774")
	("wt-tree/member?" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fmember_003f-1773")
	("wt-tree/min" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fmin-1791")
	("wt-tree/min-datum" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fmin_002ddatum-1792")
	("wt-tree/min-pair" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fmin_002dpair-1793")
	("wt-tree/rank" "Indexing-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002frank-1790")
	("wt-tree/set-equal?" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fset_002dequal_003f-1783")
	("wt-tree/size" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fsize-1770")
	("wt-tree/split<" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fsplit_003c-1777")
	("wt-tree/split>" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fsplit_003e-1778")
	("wt-tree/subset?" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002fsubset_003f-1782")
	("wt-tree/union" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002funion-1779")
	("wt-tree/union-merge" "Advanced-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_002funion_002dmerge-1786")
	("wt-tree?" "Basic-Operations-on-Weight_002dBalanced-Trees.html#index-wt_002dtree_003f-1768")
	("x-character-bounds/ascent" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dcharacter_002dbounds_002fascent-3090")
	("x-character-bounds/descent" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dcharacter_002dbounds_002fdescent-3091")
	("x-character-bounds/lbearing" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dcharacter_002dbounds_002flbearing-3087")
	("x-character-bounds/rbearing" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dcharacter_002dbounds_002frbearing-3088")
	("x-character-bounds/width" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dcharacter_002dbounds_002fwidth-3089")
	("x-close-all-displays" "Utilities-for-X-Graphics.html#index-x_002dclose_002dall_002ddisplays-3044")
	("x-font-structure/all-chars-exist" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fall_002dchars_002dexist-3079")
	("x-font-structure/character-bounds" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fcharacter_002dbounds-3084")
	("x-font-structure/default-char" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fdefault_002dchar-3080")
	("x-font-structure/direction" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fdirection-3078")
	("x-font-structure/max-ascent" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fmax_002dascent-3085")
	("x-font-structure/max-bounds" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fmax_002dbounds-3082")
	("x-font-structure/max-descent" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fmax_002ddescent-3086")
	("x-font-structure/min-bounds" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fmin_002dbounds-3081")
	("x-font-structure/name" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fname-3077")
	("x-font-structure/start-index" "Custom-Operations-on-X-Graphics-Devices.html#index-x_002dfont_002dstructure_002fstart_002dindex-3083")
	("x-geometry-string" "Utilities-for-X-Graphics.html#index-x_002dgeometry_002dstring-3045")
	("x-graphics/close-display" "Utilities-for-X-Graphics.html#index-x_002dgraphics_002fclose_002ddisplay-3043")
	("x-graphics/open-display" "Utilities-for-X-Graphics.html#index-x_002dgraphics_002fopen_002ddisplay-3040")
	("x-open-display" "X-Graphics-Type.html#index-x_002dopen_002ddisplay-3037")
	("x-size on output port" "Output-Port-Operations.html#index-x_002dsize-on-output-port-2210")
	("xcons" "Pairs.html#index-xcons-1123")
	("xml-!attlist" "XML-Structure.html#index-xml_002d_0021attlist-2426")
	("xml-!attlist-definitions" "XML-Structure.html#index-xml_002d_0021attlist_002ddefinitions-2431")
	("xml-!attlist-name" "XML-Structure.html#index-xml_002d_0021attlist_002dname-2430")
	("xml-!attlist?" "XML-Structure.html#index-xml_002d_0021attlist_003f-2428")
	("xml-!element" "XML-Structure.html#index-xml_002d_0021element-2418")
	("xml-!element-content-type" "XML-Structure.html#index-xml_002d_0021element_002dcontent_002dtype-2423")
	("xml-!element-name" "XML-Structure.html#index-xml_002d_0021element_002dname-2422")
	("xml-!element?" "XML-Structure.html#index-xml_002d_0021element_003f-2420")
	("xml-!entity" "XML-Structure.html#index-xml_002d_0021entity-2434")
	("xml-!entity-name" "XML-Structure.html#index-xml_002d_0021entity_002dname-2438")
	("xml-!entity-value" "XML-Structure.html#index-xml_002d_0021entity_002dvalue-2439")
	("xml-!entity?" "XML-Structure.html#index-xml_002d_0021entity_003f-2436")
	("xml-!notation" "XML-Structure.html#index-xml_002d_0021notation-2460")
	("xml-!notation-id" "XML-Structure.html#index-xml_002d_0021notation_002did-2465")
	("xml-!notation-name" "XML-Structure.html#index-xml_002d_0021notation_002dname-2464")
	("xml-!notation?" "XML-Structure.html#index-xml_002d_0021notation_003f-2462")
	("xml->string" "XML-Output.html#index-xml_002d_003estring-2332")
	("xml->wide-string" "XML-Output.html#index-xml_002d_003ewide_002dstring-2331")
	("xml-declaration" "XML-Structure.html#index-xml_002ddeclaration-2380")
	("xml-declaration-encoding" "XML-Structure.html#index-xml_002ddeclaration_002dencoding-2385")
	("xml-declaration-standalone" "XML-Structure.html#index-xml_002ddeclaration_002dstandalone-2386")
	("xml-declaration-version" "XML-Structure.html#index-xml_002ddeclaration_002dversion-2384")
	("xml-declaration?" "XML-Structure.html#index-xml_002ddeclaration_003f-2382")
	("xml-document" "XML-Structure.html#index-xml_002ddocument-2364")
	("xml-document-declaration" "XML-Structure.html#index-xml_002ddocument_002ddeclaration-2368")
	("xml-document-dtd" "XML-Structure.html#index-xml_002ddocument_002ddtd-2370")
	("xml-document-misc-1" "XML-Structure.html#index-xml_002ddocument_002dmisc_002d1-2369")
	("xml-document-misc-2" "XML-Structure.html#index-xml_002ddocument_002dmisc_002d2-2371")
	("xml-document-misc-3" "XML-Structure.html#index-xml_002ddocument_002dmisc_002d3-2373")
	("xml-document-root" "XML-Structure.html#index-xml_002ddocument_002droot-2372")
	("xml-document?" "XML-Structure.html#index-xml_002ddocument_003f-2366")
	("xml-dtd" "XML-Structure.html#index-xml_002ddtd-2408")
	("xml-dtd-external" "XML-Structure.html#index-xml_002ddtd_002dexternal-2413")
	("xml-dtd-internal" "XML-Structure.html#index-xml_002ddtd_002dinternal-2414")
	("xml-dtd-root" "XML-Structure.html#index-xml_002ddtd_002droot-2412")
	("xml-dtd?" "XML-Structure.html#index-xml_002ddtd_003f-2410")
	("xml-element" "XML-Structure.html#index-xml_002delement-2390")
	("xml-element-attributes" "XML-Structure.html#index-xml_002delement_002dattributes-2395")
	("xml-element-content" "XML-Structure.html#index-xml_002delement_002dcontent-2396")
	("xml-element-name" "XML-Structure.html#index-xml_002delement_002dname-2394")
	("xml-element?" "XML-Structure.html#index-xml_002delement_003f-2392")
	("xml-external-id" "XML-Structure.html#index-xml_002dexternal_002did-2468")
	("xml-external-id-id" "XML-Structure.html#index-xml_002dexternal_002did_002did-2472")
	("xml-external-id-uri" "XML-Structure.html#index-xml_002dexternal_002did_002duri-2473")
	("xml-external-id?" "XML-Structure.html#index-xml_002dexternal_002did_003f-2470")
	("xml-name->symbol" "XML-Names.html#index-xml_002dname_002d_003esymbol-2340")
	("xml-name-local" "XML-Names.html#index-xml_002dname_002dlocal-2346")
	("xml-name-prefix" "XML-Names.html#index-xml_002dname_002dprefix-2345")
	("xml-name-string" "XML-Names.html#index-xml_002dname_002dstring-2342")
	("xml-name-uri" "XML-Names.html#index-xml_002dname_002duri-2341")
	("xml-name=?" "XML-Names.html#index-xml_002dname_003d_003f-2349")
	("xml-name?" "XML-Names.html#index-xml_002dname_003f-2339")
	("xml-nmtoken?" "XML-Names.html#index-xml_002dnmtoken_003f-2361")
	("xml-parameter-!entity" "XML-Structure.html#index-xml_002dparameter_002d_0021entity-2442")
	("xml-parameter-!entity-name" "XML-Structure.html#index-xml_002dparameter_002d_0021entity_002dname-2446")
	("xml-parameter-!entity-value" "XML-Structure.html#index-xml_002dparameter_002d_0021entity_002dvalue-2447")
	("xml-parameter-!entity?" "XML-Structure.html#index-xml_002dparameter_002d_0021entity_003f-2444")
	("xml-processing-instructions" "XML-Structure.html#index-xml_002dprocessing_002dinstructions-2400")
	("xml-processing-instructions-name" "XML-Structure.html#index-xml_002dprocessing_002dinstructions_002dname-2404")
	("xml-processing-instructions-text" "XML-Structure.html#index-xml_002dprocessing_002dinstructions_002dtext-2405")
	("xml-processing-instructions?" "XML-Structure.html#index-xml_002dprocessing_002dinstructions_003f-2402")
	("xml-qname-local" "XML-Names.html#index-xml_002dqname_002dlocal-2353")
	("xml-qname-prefix" "XML-Names.html#index-xml_002dqname_002dprefix-2352")
	("xml-qname?" "XML-Names.html#index-xml_002dqname_003f-2351")
	("xml-unparsed-!entity" "XML-Structure.html#index-xml_002dunparsed_002d_0021entity-2450")
	("xml-unparsed-!entity-id" "XML-Structure.html#index-xml_002dunparsed_002d_0021entity_002did-2455")
	("xml-unparsed-!entity-name" "XML-Structure.html#index-xml_002dunparsed_002d_0021entity_002dname-2454")
	("xml-unparsed-!entity-notation" "XML-Structure.html#index-xml_002dunparsed_002d_0021entity_002dnotation-2456")
	("xml-unparsed-!entity?" "XML-Structure.html#index-xml_002dunparsed_002d_0021entity_003f-2452")
	("xml-uri" "XML-Names.html#index-xml_002duri-2358")
	("xmlns-uri" "XML-Names.html#index-xmlns_002duri-2359")
	("y-size" "Port-Primitives.html#index-y_002dsize-2153")
	("y-size on output port" "Output-Port-Operations.html#index-y_002dsize-on-output-port-2211")
	("zero?" "Numerical-operations.html#index-zero_003f-496")))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(provide 'mit-scheme-doc)
